function [HstTout,HstFit,FitParameters]=combfit(Hst_i,Bins_i,HistType,BinsType,ScaleMode_i,DistrNum_i,DistrType_i,DistrCustom,IntermPlotStep_i,MeanFit,AmplFit,StdFit,...
					MeanFitOpt,AmplFitOpt,StdFitOpt,MeanFitList,AmplFitList,StdFitList);
%Inputs:
%Hst	- Initial histogram
%Bins	- Bins values of the initial histogram
%HistType	- Initial histogram type - 'Histogram' for all-points histogram, 'PDF'- probability density function, where number of points divided by the bin width
%BinsType	- 'Boundaries' or 'Medians'
%ScaleMode	- 	%Mode of scaling and weighting for histograms difference calculation: 'Linear', 'Log'
%DistrNum	- number of distributions used to fit the histogram
%DistrType	- Distribution type:'Normal'

%Outputs:
%HstTout	- scaled initial histogram - total sum of all the bins is 1
%HstFit	- result of the fit
%FitParameters	- final parameters of distributions - matrix with rows of Mean(1), Standard deviation (2), and amlitude(3)

global Hst Bins ScaleMode DistrNum DistrType MinBins MaxBins IntermPlotStep WeightMatrix FitStage MeanGuessStep SumHst StdGuess
Hst=Hst_i;
Bins=Bins_i;
ScaleMode=ScaleMode_i;
DistrNum=DistrNum_i;
DistrType=DistrType_i;
IntermPlotStep=IntermPlotStep_i;

%IntermPlotStep=100;	%Every this frame will be made a control print of fitted curve. 0 - no printing
IntermPlotStep=-IntermPlotStep;	%inverted sign is a Flag of first plot

%Convert bins to boundaries bins
switch BinsType	%BinsType	- 'Boundaries' or 'Medians'
case 'Boundaries'
case 'Medians'
	Bins=[(2*Bins(1)-Bins(2)),Bins,(2*Bins(end)-Bins(end-1))];	%guessing and adding two extra bins at the beginning and the end
	Bins=(Bins(2:end)+Bins(1:(end-1)))/2;	%Guessing boundaries for the bins' medians
end

SumHst=sum(Hst);	%total probability to occur in any of states - sum of all the probabilities of the initial histogram
	
%Convert PDF to real histogram if necessary
switch HistType	%Initial histogram type - 'Histogram' for all-points histogram, 'PDF'- probability density function, where number of points divided by the bin width
case 'Histogram'
case 'PDF'
	if min(Bins)~=max(Bins)	%Not all the bins are of the same size
		BinsWidth=Bins(2:end)-Bins(1:(end-1));
		Hst=Hst.*BinsWidth;	%Converting to real histogram by multiplying by the bin width
		Hst=SumHst*Hst/sum(Hst);
	end
		
		
end	%Initial histogram type - 'Histogram' for all-points histogram, 'PDF'- probability density function, where number of points divided by the bin width

%Scale histogram
%Hst=Hst/sum(Hst);	%Sum of all the bins is 1

%Create initial parameters values for distributions 
%Paremeters are in generalized view:
%1st row - value change from -inf to inf makes change of mean from the first to the last boundary
%2nd row - standard deviation value, changing from -inf to inf, makes change of std from 0 to (MaxBins-MinBins)
%3rd row - amplitude of particular distribution, changing from -inf to inf,
% makes ampl to change from 0 to 2

MinBins=min(Bins); MaxBins=max(Bins);

%========== rough Position and Amplitude fit
FitStage='PosAmpl';	%Position and Amplitude fit
switch DistrType	%type of distributtions used for fitting
case 'Normal distribution'
	switch MeanFitOpt	%Guess values
	case 'Guess values'
		MeanGuessStep=(MaxBins-MinBins)/(DistrNum+1);
		MeanGuess=(MinBins+MeanGuessStep):MeanGuessStep:(MaxBins-MeanGuessStep);
	case 'Custom values'
		MeanGuessStep=(MaxBins-MinBins)/(DistrNum+1);
		MeanGuess=MeanFitList;
	end	%Guess values
	
	switch AmplFitOpt	%Guess values
	case 'Guess values'
		AmplGuess=sum(Hst)/DistrNum;
	case 'Custom values'
		AmplGuess=AmplFitList;
		%AmplGuess=mean(AmplFitList);
	end	%Guess values
	
	switch StdFitOpt	%Guess values
	case 'Guess values'
		StdGuess(1:DistrNum)=MeanGuessStep/4;
	case 'Custom values'
		StdGuess=StdFitList;
		%StdGuess=mean(StdFitList);
	end	%Guess values
	
	
	FitParameters(1,1:DistrNum)=range2inf(MinBins-(MaxBins-MinBins)/2,MaxBins+(MaxBins-MinBins)/2,MeanGuess);	%Initial mean values
	FitParameters(2,1:DistrNum)=range2inf(0,2*SumHst,AmplGuess);	%Initial amplitude values
case 'Custom distribution'
end	%type of distributtions used for fitting

HstTout=Hst;
switch ScaleMode	%Mode of scaling and weighting for difference calculation
case 'Linear'	%Need logscale
case 'Log'
	Hst=log10([loghst(Hst)]);
case 'LogMaxWeighted'
	CompareRange=round(length(Hst)/(1*(DistrNum+1)));	%Range in bins for highlighting maximums
	for i=1:length(Hst)
		WeightMatrixPikes(i)=(Hst(i)/mean(Hst(max(1,i-CompareRange):min(length(Hst),i+CompareRange))))^2;	%highlights pikes
		%WeightMatrixValue(i)=0;	%highlights pikes
	end
	
%	WeightMatrixValue=Hst;
	
	Hst=log10([loghst(Hst)]);
	
% 	%Pikes-downs highlighting, transitions (high slope) decreasing
% 	t=[Hst;Hst(1)];	%Circling histogram to have the same size after differentiation
%  	WeightMatrixValue=abs(diff(t));
% 	WeightMatrixValue(WeightMatrixValue==0)=min(WeightMatrixValue>0);
% 	WeightMatrixValue=(WeightMatrixValue.^(-1))';
% 	clear t;

	
% 	WeightMatrixValue=1;
%	WeightMatrixValue=(Hst-min(Hst(:))).^2;
	WeightMatrixValue=(Hst-min(Hst(:)))';


	%WeightMatrix=WeightMatrixValue;
	
	WeightMatrix=(WeightMatrixPikes.*WeightMatrixValue)';
	%WeightMatrix=WeightMatrix';
	
end		%Mode of scaling and weighting for difference calculation

%=============	Optimal fit by random search algorithm
FitParameters=reshape(FitParameters,1,size(FitParameters,1)*DistrNum);	%make and one-dimensional array

%random search settings
Npoints=length(FitParameters);	%number of independent variables
mx_stp=(20*Npoints)^2;	%Maximal evaluation steps number	
%mx_stp=3;%!!!
MaxIter=round((20*Npoints)^1.5);	%Maximal iteration steps
%dev0=2;	%parameter deviation change rate
dev0=2;	%parameter deviation change rate
dev=0.1*dev0/Npoints;	%Initial Deviation for optimization
%dev=dev0/DistrNum;	%Initial Deviation for optimization
TolX=0.0001;	%Optimization parameter exit tolerance
TolFun=0.0001;	%Optimization function exit tolerance
%dif=2;	%difference exponent between expanding and shrinking
dif=2;	%difference exponent between expanding and shrinking
dir=1;	%directed <1>, Nondirected <2>, Persistive <3> (use all possible attempts) search
msg=100;	%messaging frequency - no messages <0>, message on screen every <#> sucessfull steps
tries=Npoints;
expadd=2;	%mod of the parameter change: exponential <1> (for 0 to Inf parameters) or additive <2> (for -Inf to Inf parameters)

%figure;

[FitParameters,Function_counts,Iterations,fval]=random_search_combfit(FitParameters,'combfit_eval',mx_stp,MaxIter,...
	dev0,dev,TolX,TolFun,dif,dir,msg,tries,expadd);
if IntermPlotStep~=0	%If Add control plot of the fit curve
	hold off;
end	%If Add control plot of the fit curve

FitParameters=reshape(FitParameters,round(length(FitParameters)/DistrNum),DistrNum);
FitParameters%!
%calculate fitted distribution
HstFit=zeros(size(Hst));	%Initialize fitted distribution
for i=1:DistrNum	%cycle through separate distributions to add them
	switch DistrType	%type of distributtions used for fitting
	case 'Normal distribution'
		FitParameters(1,i)=inf2range(MinBins-(MaxBins-MinBins)/2,MaxBins+(MaxBins-MinBins)/2,FitParameters(1,i));
		%FitParameters(2,i)=inf2range(0,(MaxBins-MinBins),FitParameters(2,i));	% Standard deviation values
		FitParameters(2,i)=inf2range(0,2*SumHst,FitParameters(2,i));	% amplitude values
		BorderProb=FitParameters(2,i)*normcdf(Bins,FitParameters(1,i),StdGuess(i));	%CDF probabilities on the borders of the bins
	end	%type of distributtions used for fitting
	HstFit=HstFit+(BorderProb(2:end)-BorderProb(1:(end-1)));	%probabilities to fit into the bin
end	%cycle through separate distributions to add them

switch DistrType
case 'Normal distribution'
end
disp('Amplitude fit')
Function_counts%!!!
Iterations%!!!
FitParameters
hold off;


%========== complete fit
%IntermPlotStep=100;	%Every this frame will be made a control print of fitted curve. 0 - no printing
IntermPlotStep=-IntermPlotStep;	%inverted sign is a Flag of first plot
FitStage='PosStdAmpl';	%Position and Amplitude fit
switch DistrType	%type of distributtions used for fitting
case 'Normal distribution'
% 	MeanGuessStep=(MaxBins-MinBins)/(DistrNum+1);
% 	MeanGuess=(MinBins+MeanGuessStep):MeanGuessStep:(MaxBins-MeanGuessStep);
% 	%MeanGuess=[1.7 41 56];%!!!
% 	%MeanGuess=[0 9 28 50 60];%!!!
% 	%MeanGuess=[0 16 30 45 56];%!!!
% 	MeanGuess=[0 16 30 45 56 77];%!!!
	StdGuess=MeanGuessStep/4;
% 	AmplGuess=1/DistrNum;
% 	%AmplGuess=[0.6 0.2 0.2];%!!!
% 	AmplGuess=[0.7 0.01 0.003 0.01 0.03 0.01];%!!!
	FitParameters(1,1:DistrNum)=range2inf(MinBins-(MaxBins-MinBins)/2,MaxBins+(MaxBins-MinBins)/2,FitParameters(1,1:DistrNum));	%Initial mean values
	FitParameters(3,1:DistrNum)=range2inf(0,2*SumHst,FitParameters(2,1:DistrNum));	%Initial amplitude values
	FitParameters(2,1:DistrNum)=range2inf(0,(MaxBins-MinBins),StdGuess);	%Initial Standard deviation values
end	%type of distributtions used for fitting
FitParameters%!
% HstTout=Hst;
% switch ScaleMode	%Mode of scaling and weighting for difference calculation
% case 'Linear'	%Need logscale
% case 'Log'
% 	Hst=log10([loghst(Hst)]);
% case 'LogMaxWeighted'
% 	Hst=log10([loghst(Hst)]);
% 	for i=1:length(Hst)
% 		WeightMatrixPikes(i)=Hst(i)/mean(Hst(max(1,i-MeanGuessStep/4):min(length(Hst),i+MeanGuessStep/4)));	%highlights pikes
% 		WeightMatrixValue(i)=Hst(i)/mean(Hst(max(1,i-MeanGuessStep/4):min(length(Hst),i+MeanGuessStep/4)));	%highlights pikes
% 	end
% 	WeightMatrix=WeightMatrixPikes+WeightMatrixValue;
% 	WeightMatrix=WeightMatrix';
% end		%Mode of scaling and weighting for difference calculation

%=============	Optimal fit by random search algorithm
FitParameters=reshape(FitParameters,1,size(FitParameters,1)*DistrNum);	%make and one-dimensional array

%random search settings
Npoints=length(FitParameters);	%number of independent variables
mx_stp=(20*Npoints)^2;	%Maximal evaluation steps number	
%mx_stp=10;%!!!
MaxIter=round((20*Npoints)^1.5);	%Maximal iteration steps
%dev0=2;	%parameter deviation change rate
dev0=2;	%parameter deviation change rate
dev=0.1*dev0/Npoints;	%Initial Deviation for optimization
%dev=dev0/DistrNum;	%Initial Deviation for optimization
TolX=0.0001;	%Optimization parameter exit tolerance
TolFun=0.0001;	%Optimization function exit tolerance
%dif=2;	%difference exponent between expanding and shrinking
dif=2;	%difference exponent between expanding and shrinking
dir=1;	%directed <1>, Nondirected <2>, Persistive <3> (use all possible attempts) search
msg=100;	%messaging frequency - no messages <0>, message on screen every <#> sucessfull steps
tries=Npoints;
expadd=2;	%mod of the parameter change: exponential <1> (for 0 to Inf parameters) or additive (for -Inf to Inf parameters)


[FitParameters,Function_counts,Iterations,fval]=random_search_combfit(FitParameters,'combfit_eval',mx_stp,MaxIter,...
	dev0,dev,TolX,TolFun,dif,dir,msg,tries,expadd);
if IntermPlotStep~=0	%If Add control plot of the fit curve
	hold off;
end	%If Add control plot of the fit curve

FitParameters=reshape(FitParameters,round(length(FitParameters)/DistrNum),DistrNum);
%calculate fitted distribution
HstFit=zeros(size(Hst));	%Initialize fitted distribution
for i=1:DistrNum	%cycle through separate distributions to add them
	switch DistrType	%type of distributtions used for fitting
	case 'Normal distribution'
		FitParameters(1,i)=inf2range(MinBins-(MaxBins-MinBins)/2,MaxBins+(MaxBins-MinBins)/2,FitParameters(1,i));
		FitParameters(2,i)=inf2range(0,(MaxBins-MinBins),FitParameters(2,i));	% Standard deviation values
		FitParameters(3,i)=inf2range(0,2*SumHst,FitParameters(3,i));	% amplitude values
		BorderProb=FitParameters(3,i)*normcdf(Bins,FitParameters(1,i),FitParameters(2,i));	%CDF probabilities on the borders of the bins
	end	%type of distributtions used for fitting
	HstFit=HstFit+(BorderProb(2:end)-BorderProb(1:(end-1)));	%probabilities to fit into the bin
end	%cycle through separate distributions to add them

switch DistrType
case 'Normal distribution'
end
disp('Complete fit')
Function_counts%!!!
Iterations%!!!
FitParameters



function	Out=range2inf(A,B,In)

%Inputs:
%A - lower boundary
%B - upper boundary
%In - value in the range

%Outputs:
%Out - value from -Inf to Inf

Out=-log((B-A)./(In-A)-1);

function	Out=inf2range(A,B,In)

%Inputs:
%A - lower boundary
%B - upper boundary
%In - value from -Inf to Inf

%Outputs:
%Out - value in the range

Out=A+(B-A)*(1./(1+exp(-In)));

function	Out=range2halfinf(A,B,In)

%Inputs:
%A - lower boundary
%B - upper boundary
%In - value in the range

%Outputs:
%Out - value from 0 to Inf

Out=-log((In-B)/(A-B));

function	Out=halfinf2range(A,B,In)

%Inputs:
%A - lower boundary
%B - upper boundary
%In - value from 0 to Inf

%Outputs:
%Out - value in the range

Out=B+(A-B)*exp(-In);

