%dwtan - program for dwelling time analysis
dbstop if error
dbstop if warning

%cd 'C:\Andrey\Other-\Matlab\Patching\Data'
%cd 'C:\Biophysics\ANDREY\MODELING\Patching\Data'
ChangeDir

FileList=dwtopendlg;	%Selecting files for analysis
if ~isempty(FileList)
    FidO=fopen('dwtan_result.txt','w');
    for j=1:length(FileList)
        
        [Dwt,DataNotes]=dwtopen(FileList{j});
        %dwtinvrs(FileList{i});
        Dwt(1,:)=Dwt(1,:)+1; %Shift state number 1 unit up
        MaxS=max(Dwt(1,:));  %maximal number of different states
        State1=Dwt(1,1:(end-2)); %Vector of states 1
        State2=Dwt(1,2:(end-1)); %Vector of states 2
        DwTime2=Dwt(2,2:(end-1)); %Vector of dwelling times for states 2
        State3=Dwt(1,3:end); %Vector of states 3
        DHst=zeros(MaxS,MaxS,MaxS); %Array of transitions numbers
        DTHst=num2cell(DHst); %Array of dwelling times vectors, filled by zeros
        for i=1:length(State1)
            DTHst{State1(i),State2(i),State3(i)}(end+1)=DwTime2(i);
            DHst(State1(i),State2(i),State3(i))=DHst(State1(i),State2(i),State3(i))+1;
        end
        
        Barrier=2;   %Minimum number of events to be considered
        if MaxS>2   %minimum 3 states for the process to me non-markov
            NonM(MaxS,j)=0;
            NonMUp(MaxS,j)=0;
            NonMDn(MaxS,j)=0;
            
            DnPTimeM(MaxS,j)=0;  %Mean dwelling time after moving down
            DnPTimeS(MaxS,j)=0;  %Standard deviation for dwelling time after moving down
            UpPTimeM(MaxS,j)=0;  %Mean dwelling time after moving up
            UpPTimeS(MaxS,j)=0;  %Standard deviation for dwelling time after moving up
            
            DnPDnTimeM(MaxS,j)=0;  %Mean dwelling time after moving down
            DnPDnTimeS(MaxS,j)=0;  %Standard deviation for dwelling time after moving down
            UpPDnTimeM(MaxS,j)=0;  %Mean dwelling time after moving up
            UpPDnTimeS(MaxS,j)=0;  %Standard deviation for dwelling time after moving up
            
            DnPUpTimeM(MaxS,j)=0;  %Mean dwelling time after moving down
            DnPUpTimeS(MaxS,j)=0;  %Standard deviation for dwelling time after moving down
            UpPUpTimeM(MaxS,j)=0;  %Mean dwelling time after moving up
            UpPUpTimeS(MaxS,j)=0;  %Standard deviation for dwelling time after moving up
            
            Nevnt=sum(sum(DHst,3),1);  %Total number of events for this state
            for i=2:(MaxS-1)
                if (sum(DHst(i-1,i,:))>=Barrier)&(sum(DHst(i+1,i,:))>=Barrier)
                    NonM(i,j)=(sum((DHst(i-1,i,:)/sum(DHst(i-1,i,:))-...
                        DHst(i+1,i,:)/sum(DHst(i+1,i,:))).^2))^.5; %check "NonMarkovity of the process = from 0 to 1
                    UpPUp=DHst(i-1,i,i+1);
                    UpPDn=DHst(i-1,i,i-1);
                    DnPUp=DHst(i+1,i,i+1);
                    DnPDn=DHst(i+1,i,i-1);
                    UpP=sum(DHst(i-1,i,:));  %portion of up transitions to this point
                    DnP=sum(DHst(i+1,i,:));  %portion of down transitions to this point
                    if [DnPUp,UpP,DnP]~=0
                        NonMUp(i,j)=(UpPUp/DnPUp)/(UpP/DnP);   %Prerogative of 2 up
                    else
                        NonMUp(i,j)=0;
                    end
                    
                    if [UpPDn,UpP,DnP]~=0
                        NonMDn(i,j)=(DnPDn/UpPDn)/(DnP/UpP);  %Prerogative of 2 down
                    else
                        NonMDn(i,j)=0;
                    end
                    
                    
                    DnPTimeM(i,j)=mean([DTHst{i+1,i,:}]);  %Mean dwelling time after moving down
                    DnPTimeS(i,j)=std([DTHst{i+1,i,:}]);  %Standard deviation for dwelling time after moving down
                    UpPTimeM(i,j)=mean([DTHst{i-1,i,:}]);  %Mean dwelling time after moving up
                    UpPTimeS(i,j)=std([DTHst{i-1,i,:}]);  %Standard deviation for dwelling time after moving up
                    
                    DnPDnTimeM(i,j)=mean([DTHst{i+1,i,i-1}]);  %Mean dwelling time after moving down
                    DnPDnTimeS(i,j)=std([DTHst{i+1,i,i-1}]);  %Standard deviation for dwelling time after moving down
                    UpPDnTimeM(i,j)=mean([DTHst{i-1,i,i-1}]);  %Mean dwelling time after moving up
                    UpPDnTimeS(i,j)=std([DTHst{i-1,i,i-1}]);  %Standard deviation for dwelling time after moving up
                    
                    DnPUpTimeM(i,j)=mean([DTHst{i+1,i,i+1}]);  %Mean dwelling time after moving down
                    DnPUpTimeS(i,j)=std([DTHst{i+1,i,i+1}]);  %Standard deviation for dwelling time after moving down
                    UpPUpTimeM(i,j)=mean([DTHst{i-1,i,i+1}]);  %Mean dwelling time after moving up
                    UpPUpTimeS(i,j)=std([DTHst{i-1,i,i+1}]);  %Standard deviation for dwelling time after moving up
                end
            end
%             NonMDn
%             DnPTimeM
            
            fprintf(FidO,'%s\t %s\n','File Name:',FileList{j});
            fprintf(FidO,'%s\t %s\n','Data Notes:',DataNotes);
            fprintf(FidO,'%s\t %g\n','Number of Channels:',MaxS);
            
            fprintf(FidO,'%s\t','Nevnt:');
            fprintf(FidO,'%g\t', Nevnt);
            fprintf(FidO,'\n');
            
            fprintf(FidO,'%s\t','NonM:');
            fprintf(FidO,'%g\t', NonM(:,j));
            fprintf(FidO,'\n');
            
            fprintf(FidO,'%s\t','NonMUp:');
            fprintf(FidO,'%g\t', NonMUp(:,j));
            fprintf(FidO,'\n');
            
            fprintf(FidO,'%s\t','NonMDn:');
            fprintf(FidO,'%g\t', NonMDn(:,j));
            fprintf(FidO,'\n');
            
            
            fprintf(FidO,'%s\t','DnPTimeM:');
            fprintf(FidO,'%g\t',DnPTimeM(:,j));   %Mean dwelling time after moving down
            fprintf(FidO,'\n');
            
            fprintf(FidO,'%s\t','DnPTimeS:');
            fprintf(FidO,'%g\t',DnPTimeS(:,j));   %Standard deviation for dwelling time after moving down
            fprintf(FidO,'\n');
            
            fprintf(FidO,'%s\t','UpPTimeM:');
            fprintf(FidO,'%g\t',UpPTimeM(:,j));  %Mean dwelling time after moving up
            fprintf(FidO,'\n');
            
            fprintf(FidO,'%s\t','UpPTimeS:');
            fprintf(FidO,'%g\t',UpPTimeS(:,j));  %Standard deviation for dwelling time after moving up
            fprintf(FidO,'\n');
            
            
            fprintf(FidO,'%s\t','DnPDnTimeM:');
            fprintf(FidO,'%g\t',DnPDnTimeM(:,j));  %Mean dwelling time after moving down
            fprintf(FidO,'\n');
            
            fprintf(FidO,'%s\t','DnPDnTimeS:');
            fprintf(FidO,'%g\t',DnPDnTimeS(:,j));  %Standard deviation for dwelling time after moving down
            fprintf(FidO,'\n');
            
            
            
            
            fprintf(FidO,'%s\t','UpPDnTimeM:');
            fprintf(FidO,'%g\t',UpPDnTimeM(:,j));  %Mean dwelling time after moving up
            fprintf(FidO,'\n');
            
            fprintf(FidO,'%s\t','UpPDnTimeS:');
            fprintf(FidO,'%g\t',UpPDnTimeS(:,j));  %Standard deviation for dwelling time after moving up
            fprintf(FidO,'\n');
            
            
            fprintf(FidO,'%s\t','DnPUpTimeM:');
            fprintf(FidO,'%g\t',DnPUpTimeM(:,j));  %Mean dwelling time after moving down
            fprintf(FidO,'\n');
            
            fprintf(FidO,'%s\t','DnPUpTimeS:');
            fprintf(FidO,'%g\t',DnPUpTimeS(:,j));  %Standard deviation for dwelling time after moving down
            fprintf(FidO,'\n');
            
            fprintf(FidO,'%s\t','UpPUpTimeM:');
            fprintf(FidO,'%g\t',UpPUpTimeM(:,j));  %Mean dwelling time after moving up
            fprintf(FidO,'\n');
            
            fprintf(FidO,'%s\t','UpPUpTimeS:');
            fprintf(FidO,'%g\t',UpPUpTimeS(:,j));  %Standard deviation for dwelling time after moving up
            fprintf(FidO,'\n');
            
            
            fprintf(FidO,'\n');
        end
        
    end
    DHst
    NonM
    NonMUp
    NonMDn
    fclose(FidO);
end