%histplot - function for plotting 2D and 1D histograms, created by twodimhist.m function
function hp=histplot(BinsX,BinsY,Hst,AutoX,MinX,MaxX,LogX,RevX,gridX,meshX,NormX,NormRelX,NormRelSubX,LabelX,AutoY,MinY,MaxY,...
   LogY,RevY,gridY,meshY,NormY,NormRelY,NormRelSubY,LabelY,AutoZ,MinZ,MaxZ,LogZ,RevZ,gridZ,ContZ,NormZ,LabelZ,LabelHst,...
   HistTrc,Dimn,ColMap,Lighting,HprFcn,PlotBinX)
global LastFigure
%Output:
%hp -	empty function.

%Inputs:
%BinsX -	X axis bins' boundaries values
%BinsY -	Y axis bins' boundaries values
%Hst -	Input histogram matrix
%AutoX -	Autoscale X axis <1*>, or not <0>
%MinX -	Minimal value for X axis scale
%MaxX -	Maximal value for X axis scale
%LogX -	Logarithmic <1>, or linear <0*> Y scale
%AutoY -	Autoscale Y axis <1*>, or not <0>
%MinY -	Minimal value for Y axis scale
%MaxY -	Maximal value for Y axis scale
%LogY -	Logarithmic <1>, or linear <0*> Y scale
%AutoZ -	Autoscale Z axis <1*>, or not <0>
%MinZ -	Minimal value for Z axis scale
%MaxZ -	Maximal value for Z axis scale
%LogZ -	Logarithmic <1>, or linear <0*> Z scale
%HistTrc - Plot Histogram <1*> or the trace curve <2>
%Dimn -	Tracing dimention
%NormX -	Flag for normalizing X  bins before plotting
%NormRelX -	Value to normalize X  bins relative  to (NormRelX-NormRelSubX)this value as 1
%NormRelSubX -	Value to substract from the histogram X  bins values, before scaling

%PlotBinX - Option to plot bins' boundaries on the trace plot


LabelAdd='';
switch HistTrc
case 1
   if ~AutoX;	%Cutting out excessive parts of histogram matrix
      BinsXn=find((BinsX>MinX)&(BinsX<MaxX));
      MinXn=max(1,(min(BinsXn)-1));
      MaxXn=min(length(BinsX),(max(BinsXn)+1));
      BinsX=BinsX(MinXn:MaxXn);
      Hst=Hst(MinXn:(MaxXn-1),:);
   end
   if ~AutoY;	%Cutting out excessive parts of histogram matrix
      BinsYn=find((BinsY>MinY)&(BinsY<MaxY));
      MinYn=max(1,(min(BinsYn)-1));
      MaxYn=min(length(BinsY),(max(BinsYn)+1));
      BinsY=BinsY(MinYn:MaxYn);
      Hst=Hst(:,MinYn:(MaxYn-1));
   end
   if NormX
      if (NormRelSubX~=0);	%Substracting NormRelSubX from X axis values 
         BinsX=BinsX-NormRelSubX;
         MinX=MinX-NormRelSubX;
         MaxX=MaxX-NormRelSubX;
      end
      if (NormRelX~=0)&(NormRelX~=1);	%Normalizing X axis values relative to NormRelX
         NormRelX=NormRelX-NormRelSubX;
         BinsX=BinsX/NormRelX;
         MinX=MinX/NormRelX;
         MaxX=MaxX/NormRelX;
      end
   end
   if NormY
      if (NormRelSubY~=0);	%Substracting NormRelSubY from Y axis values 
         BinsY=BinsY-NormRelSubY;
         MinY=MinY-NormRelSubY;
         MaxY=MaxY-NormRelSubY;
      end
      if (NormRelY~=0)&(NormRelY~=1);	%Normalizing Y axis values relative to NormRelY
         NormRelY=NormRelY-NormRelSubY;
         BinsY=BinsY/NormRelY;
         MinY=MinY/NormRelY;
         MaxY=MaxY/NormRelY;
      end
   end
   
   %*** Creation bins' bunradies for plotting
   for i=1:(length(BinsX)-1)
      BinsXp(i)=(BinsX(i)+BinsX(i+1))/2;	%Assignin a bin boundaries mean as a plot bin value
   end
   
   for i=1:(length(BinsY)-1)
      BinsYp(i)=(BinsY(i)+BinsY(i+1))/2;	%Assignin a bin boundaries mean as a plot bin value
   end
   
   switch HprFcn	%Hyperfunction applied to z
   case 1	%'(None)'
   case 2	%'z/(1-z)'
	Hst=Hst./(1-Hst);
	MinZ=MinZ/(1-MinZ);
	MaxZ=MaxZ/(1-MaxZ); LabelZ=['z/(1-z) of ',LabelZ];
   case 3	%'z*x'
	for i=1:length(BinsXp)
	   Hst(i,:)=Hst(i,:)*BinsXp(i);
	end
   case 4	%'z*y'
   	for i=1:length(BinsYp)
	   Hst(:,i)=Hst(:,i)*BinsYp(i);
	end
   end
   
   
   if LogZ; Hst=log10([loghst(Hst)]);
	if MinZ==0
	   MinZ=min(min(Hst));
	else
	MinZ=log10(MinZ);
      end
      MaxZ=log10(MaxZ); LabelZ=['Log of ', LabelZ]; end
   if NormZ; 
      NormRelZ=(sum(sum(Hst(find(Hst>=1)))));
      Hst=Hst/NormRelZ;
      MinZ=MinZ/NormRelZ;
      MaxZ=MaxZ/NormRelZ;
   end
   if ~AutoZ;	%Cutting out excessive values of histogram matrix
      if MinZ>min(min(Hst));	%Minimal value for Z
         Hst(Hst<MinZ)=MinZ;
      end
      if MaxZ<max(max(Hst));	%Maximal value for Z
         Hst(Hst>MaxZ)=MaxZ;
      end
   end
   
   
   Hst=Hst';
   
   %***	Plotting the surface
   figure;
   switch ColMap
   case 1
      colormap('autumn')
   case 2
      colormap('bone')
   case 3
      colormap('colorcube')
   case 4
      colormap('cool')
   case 5
      colormap('copper')
   case 6
      colormap('flag')
   case 7
      colormap('gray')
   case 8
      colormap('hot')
   case 9
      colormap('hsv')
   case 10
      colormap('jet')
   case 11
      colormap('lines')
   case 12
      colormap('pink')
   case 13
      colormap('prism')
   case 14
      colormap('spring')
   case 15
      colormap('summer')
   case 16
      colormap('winter')
   case 17	%Steel
      colormap('bone')
   case 18	%negative
      colormap('gray')
	colormap(1-colormap);
end
   
   
   switch ContZ
   case 1	%'SurfL'
      hp=surfl(BinsXp,BinsYp,Hst);
      shading interp
      set(hp,'EdgeColor','k')
      light('Position',[ -50 -250 3000 ])
      switch Lighting
      case 1
         lighting none
      case 2
         lighting flat
      case 3
         lighting gouraud
      case 4
         lighting phong
      end
      %material([0.4,0.6,0.5,30])
      if ColMap==17
         set(hp,'FaceColor',[0.7 0.8 0.8],'BackFaceLighting','lit')
      else
         set(hp,'BackFaceLighting','lit')
      end
      if meshX
         set(hp,'LineStyle','-');
         if meshY
            set(hp,'MeshStyle','both');
         else
            set(hp,'MeshStyle','row');
         end
      else
         if meshY
            set(hp,'LineStyle','-');
            set(hp,'MeshStyle','column');
         else
            set(hp,'LineStyle','none');
         end
      end
      view([20,70])
   case 2	%'Surf'
      hp=surf(BinsXp,BinsYp,Hst);
      shading interp
      set(hp,'EdgeColor','k')
      if meshX
         set(hp,'LineStyle','-');
         if meshY
            set(hp,'MeshStyle','both');
         else
            set(hp,'MeshStyle','row');
         end
      else
         if meshY
            set(hp,'LineStyle','-');
            set(hp,'MeshStyle','column');
         else
            set(hp,'LineStyle','none');
         end
      end
      view([30,25])
   case 3	%'SurfC'
      hp=surfl(BinsXp,BinsYp,Hst);
      shading interp
      set(hp,'EdgeColor','k')
      light('Position',[ -50 -250 3000 ])
      switch Lighting
      case 1
         lighting none
      case 2
         lighting flat
      case 3
         lighting gouraud
      case 4
         lighting phong
      end
      set(hp,'BackFaceLighting','lit')
      if meshX
         set(hp,'LineStyle','-');
         if meshY
            set(hp,'MeshStyle','both');
         else
            set(hp,'MeshStyle','row');
         end
      else
         if meshY
            set(hp,'LineStyle','-');
            set(hp,'MeshStyle','column');
         else
            set(hp,'LineStyle','none');
         end
      end
      hold on
      hp=contour3(BinsXp,BinsYp,Hst,24);
      hold off
      view([30,25])
   case 4	%'Contour'
      hp=contour(BinsXp,BinsYp,Hst,32);
   case 5	%'Contour3D'
      hp=contour3(BinsXp,BinsYp,Hst,32);
      view([30,25])
   case 6	%'Mesh'
      %hp=mesh(BinsXp,BinsYp,Hst,'FaceColor','none');
      hp=surf(BinsXp,BinsYp,Hst);
      set(hp,'EdgeColor','k')
      set(hp,'FaceColor','none')
      if meshX
         set(hp,'LineStyle','-');
         if meshY
            set(hp,'MeshStyle','both');
         else
            set(hp,'MeshStyle','row');
         end
      else
         if meshY
            set(hp,'LineStyle','-');
            set(hp,'MeshStyle','column');
         else
            set(hp,'LineStyle','none');
         end
      end
      %view([30,25])
      view([0,0])
   case 7	%'Gradient'
      [px,py] = gradient(Hst);
      quiver(BinsXp,BinsYp,px,py);    
   case 8	%'Slice'
      sx=fix([length(BinsXp)/4,length(BinsXp)/2,3*length(BinsXp)/4]);
      sy=fix([length(BinsYp)/4,length(BinsYp)/2,3*length(BinsYp)/4]);
      sz=fix((min(Hst)+max(Hst))/2);
      hp=slice(Hst,sx,sy,sz);
      %hp=slice(BinsXp,BinsYp,BinsZp,Hst,sx,sy,sz);
      view([30,25])
      %view([30,25])
   case 9	%'Pcolor'
      hp=pcolor(BinsXp,BinsYp,Hst);
   end
   %set(gcf,'Position',[ 1 1 780 580 ])
   %set(gca,'CameraViewAngleMode','Auto')
   %set(gca,'Projection','Perspective')
   %set(gca,'CameraPosition',[ 1433.39523631156 -145.697802478982 107958.273181475 ])
   %set(gca,'CameraViewAngle',10.339584907202)
   
   %set(hp,'LineStyle','-')
   %set(gca,'XDir','reverse')
   if ~AutoZ; set(gca,'ZLimMode','manual'); set(gca,'ZLim',[MinZ MaxZ]); else set(gca,'ZLimMode','auto');  end
   %if LogZ; set(gca,'ZScale','log'); else set(gca,'ZScale','linear'); end
   
   if gridZ; set(gca,'ZGrid','on');else set(gca,'ZGrid','off'); end
   if RevZ; set(gca,'ZDir','reverse');else set(gca,'ZDir','normal'); end
   set(gca,'ZLabel',text('String',LabelZ));
   if LogY; set(gca,'YScale','log'); else set(gca,'YScale','linear'); end
   
   
   
case 2	%Plotting the trace
   if NormX&(NormRelX~=0);	%Normalizing X axis values relative to NormRelX
      BinsX=BinsX/NormRelX;
      MinX=MinX/NormRelX;
      MaxX=MaxX/NormRelX;
   end
   if NormY&(NormRelY~=0);	%Normalizing Y axis values relative to NormRelY
      BinsY=BinsY/NormRelY;
      MinY=MinY/NormRelY;
      MaxY=MaxY/NormRelY;
   end
   
   %*** Creation bins' bunradies for plotting
   for i=1:(length(BinsX)-1)
      BinsXp(i)=(BinsX(i)+BinsX(i+1))/2;	%Assignin a bin boundaries mean as a plot bin value
   end
   
   for i=1:(length(BinsY)-1)
      BinsYp(i)=(BinsY(i)+BinsY(i+1))/2;	%Assignin a bin boundaries mean as a plot bin value
   end

   switch HprFcn	%Hyperfunction applied to z
   case 1	%'(None)'
   case 2	%'z/(1-z)'
	Hst(Hst==1)=max(Hst(Hst<1));	%Replacing unit values to nearest maximal
	Hst=Hst./(1-Hst);
	if ~AutoZ
	   if (MaxZ==1|MinZ==1)
		AutoZ=1;
	   else
		MaxZt=MinZ/(1-MinZ);
		MinZ=MaxZ/(1-MaxZ);
		MaxZ=MaxZt;
	   end
	end
	LabelAdd=['z/(1-z) of ', LabelAdd];
   case 3	%'z*x'
	% 	for i=1:length(BinsXp)
	% 	   Hst(i,:)=Hst(i,:)*BinsXp(i);
	% 	end
   case 4	%'z*y'
%    	for i=1:length(BinsYp)
% 	   Hst(:,i)=Hst(:,i)*BinsYp(i);
% 	end
   end

   
   if LogZ; Hst=log10([loghst(Hst)]);
      if MinZ==0
         MinZ=min(min(Hst));
      else
         MinZ=log10(MinZ);
      end
      MaxZ=log10(MaxZ); 
	LabelAdd=['Log of ', LabelAdd];
   end
   if NormZ; 
      NormRelZ=(sum(sum(Hst(find(Hst>=1)))));
      Hst=Hst/NormRelZ;
      MinZ=MinZ/NormRelZ;
      MaxZ=MaxZ/NormRelZ;
   end
   
   
   
   
   if Dimn==1	%X
      BinsTp=BinsXp;
	LabelHst=[LabelHst,' (',LabelY,' ',num2str(MinY),' - ',num2str(MaxY),')'];
   else
	LabelHst=[LabelHst,' (',LabelX,' ',num2str(MinX),' - ',num2str(MaxX),')'];
      BinsTp=BinsYp;
      [LabelX,LabelY]=swap(LabelX,LabelY);
      MinX=MinY;
      MaxX=MaxY;
      AutoX=AutoY;
      LogX=LogY;
      gridX=gridY;
      RevX=RevY;
   end
   MinY=MinZ;
   MaxY=MaxZ;
   AutoY=AutoZ;
   LogY=LogZ;
   gridY=gridZ;
   RevY=RevZ;
   LabelY=[LabelAdd,'probability of ',LabelX];
   figure
   hp=plot(BinsTp,Hst);
   if PlotBinX	%Plot bins' boundaries
	   hold on
	   if Dimn==1	%
		   BinsT=BinsX;
	   else
		   BinsT=BinsY;
	   end
	   MinBin=min(Hst(:));
	   MaxBin=max(Hst(:));

	   for i=1:length(BinsT)	%Plot vertical lines
		  plot([BinsT(i) BinsT(i)],[MinBin MaxBin],'color','magenta');
	   end
	   
	   hold off
   end	%Plot bins' boundaries
   
	   
   if meshX %Plot spline interpolation
       hold on
       BinsSpline=min(BinsTp):(max(BinsTp)-min(BinsTp))/(10*length(BinsTp)):max(BinsTp);
       plot(BinsSpline,spline(BinsTp,Hst,BinsSpline),'-c')
       hold off
   end %Plot spline interpolation
   
end
if ~AutoX; set(gca,'XLimMode','manual'); set(gca,'XLim',[MinX MaxX]); else set(gca,'XLimMode','auto');  end
if ~AutoY; set(gca,'YLimMode','manual'); set(gca,'YLim',[MinY MaxY]); else set(gca,'YLimMode','auto');  end 
if LogX; set(gca,'XScale','log'); else set(gca,'XScale','linear'); end

if gridX; set(gca,'XGrid','on');else set(gca,'XGrid','off'); end
if gridY; set(gca,'YGrid','on');else set(gca,'YGrid','off'); end
if RevX; set(gca,'XDir','reverse');else set(gca,'XDir','normal'); end
if RevY; set(gca,'YDir','reverse');else set(gca,'YDir','normal'); end

set(gca,'XLabel',text('String',LabelX,'Interpreter','none'));
set(gca,'YLabel',text('String',LabelY,'Interpreter','none'));
set(gca,'Title',text('String',LabelHst,'Interpreter','none'));
set(gcf,'Color','white')

LastFigure=gcf;