%Program for simulation of activation curves in multichannel patch with multisubtate channels dispersed in energy


%*****************   Initial parameters:
%________  User-defined

%___ Load substates conductance, dE, dA from the file - file has 1 header line and 3 columns, for substate conductance, DeltaE and DeltaA respectively
FileName=[];	%Initialize filename
FileName={'WT_MscL_substates_reconstructed.txt'};	%Default filename
%FileName={'WT_MscL_substates.txt'};	%Default filename
%FileName={'WT_MscL_substates_relO.txt'};	%Default filename
%FileName={'test.txt'};	%Default filename
%FileName={'WT_MscL_C-S0.13-O.txt'};	%Default filename
%FileName={'WT_MscL_C-S0.13h-O.txt'};	%Default filename
%FileName={'WT_MscL_S0.13.txt'};	%Default filename
v='C:\Andrey\Other-\Matlab\Patching\Data';	%Default folder
if isempty(FileName)
	ft='*.txt';	%extension 
	[FileName,v]=uigetfiles(ft,'Select the distribution file:');	%Dialog to select file
end
cd(v);
AllSubstateParameters=textread(FileName{1},'%f','headerlines',1);
AllSubstateParameters=reshape(AllSubstateParameters,3,length(AllSubstateParameters)/3)';
Conductance=AllSubstateParameters(:,1);	%Conductance of every substate (usually in relative units)
DeltaE=AllSubstateParameters(:,2);	%initial opening energy difference for every substate, in kT
DeltaA=AllSubstateParameters(:,3);	%Expantion area of the substate - in nm^2

%___ Manually assigned parameters
ExprDeltaE=32.41;	%initial opening energy difference for MscL, in kT - Value from experiment, for plots
ExprDeltaA=12.75;	%Expantion area of the channel - in nm^2 - Value from experiment, for plots
MinDeltaA=1;	%Minimal value for channel expansion area	 - for sampling for different channel expansion areas
MaxDeltaA=23.3;	%Maximal value for channel expansion area	 - for sampling for different channel expansion areas
DispMode='Fraction';	%Mode of parameters dispersion for every substate - 'Fraction' or 'Absolute' value
MindA=0;	%Minimal standard deviation in area between channels, nm^2 or Fraction, depending on DispMode
MaxdA=0.1;	%Maximal standard deviation in area between channels, nm^2 or Fraction, depending on DispMode
%MaxdA=DeltaA*0.15;	%Maximal standard deviation in area between channels, nm^2
AreaSteps=5001;	%Number of steps in testing different area values between min and max
% RepeatAreaSteps=10;	%Number of repetitions for the dA range
T0=300;	%Temperature in kelvins
%Nchan=200;	%Number of channels in patch
Nchan=100;	%Number of channels in patch
ChannelsNumber=[];
%ChannelsNumber(1:5)=1;
%ChannelsNumber(1:15)=50; 
%ChannelsNumber(16:30)=5;	%Number of channels in patch   - for sampling simulation
ChannelsNumber(1:30)=50;	%Number of channels in patch   - for sampling simulation
MinGamma=0;	%Minimal tension for making activation curve
MaxGamma=20;	%Maximal tension for making activation curve
GammaSteps=100;	%Number of Tension steps in each activation curve
MindE=0;	%Minimal standard deviation in energy between channels, kT or Fraction, depending on DispMode
MaxdE=0.1;	%Maximal standard deviation in energy between channels, kT or Fraction, depending on DispMode
%MaxdE=DeltaE*0.15;	%Maximal standard deviation in energy between channels, kT
%dESampling=0;	%Standard deviation in energy between channels, for sampling, kT
dESampling=DeltaE*0.05;	%Standard deviation in energy between channels, for sampling, kT
dASampling=1.2;	%Standard deviation in area between channels, for sampling, nm^2
%dASampling=0;	%Standard deviation in area between channels, for sampling, nm^2
%dETime=2.9;	%Standard deviation in energy of every channel with time - from one pressure step to another, kT
dETime=0;	%Standard deviation in energy of every channel with time - from one pressure step to another, kT
%dATime=0.1;	%Standard deviation in area of every channel with time - from one pressure step to another, nm^2
dATime=0;	%Standard deviation in area of every channel with time - from one pressure step to another, nm^2
% dESampling=1.9;	%Standard deviation in energy between channels, for sampling, kT
% dASampling=0.8;	%Standard deviation in area between channels, for sampling, nm^2
EnergySteps=1001;	%number of steps in standard deviation of energy
MindEA=0;	%Minimal standard deviation in energy between channels, Fraction
%MindEA=0.029245-0.000000001;	%Minimal standard deviation in energy between channels, Fraction
%MaxdEA=0.029245+0.000000001;	%Maximal standard deviation in energy between channels, Fraction
MaxdEA=0.1;	%Maximal standard deviation in energy between channels, Fraction
EnergyAreaSteps=5001;	%number of steps in standard deviation of energy
MinPoPc=0.01;	%Minimal observable Po/Pc ratio
%MinPoPc=0.1;	%Minimal observable Po/Pc ratio
%MaxPoPc=100;	%Maximal observable Po/Pc ratio
MaxPoPc=10;	%Maximal observable Po/Pc ratio
PlotInterm=0;	%plot intermediate results of calculation
PlotAreaEffect=0;	%Plot results of area change
RandomizeEveryStep=1;	%Regenerate random numbers at every dispersion value
%RandomizeEveryStep=0;	%Regenerate random numbers at every dispersion value
SaveResults=1;	%Option to save simulation results in the file
SaveEndSummary=1;	%Option to save summary with ApDeltaA, ApDeltaE  at the max value of parameter dispersion in the file
SaveImage=1;	%Option to save picture image as an PNG file


CalcMode='dEA';	%Mode of calculations:  'dE' 'dA' 'dEA' 

dE=[]; dEA=[]; Po=[]; Gamma=[]; dEhalf=[]; DeltaAs=[]; dA=[]; PoPc=[]; PoPct=[]; Pot=[]; Pos=[];
		ApDeltaE=[]; ApDeltaA=[]; ApGamma05=[];
		DeltaEs=[]; DeltaAs=[];

%Parameters
kb=1.380658E-23;	%Boltzmann's constant, J/K
kT=kb*T0;	%kT value, in J
Gamma05=4.0474*DeltaE/DeltaA;	%Tension of half-saturation of activation curve, in dyne/cm
g=1:GammaSteps;	Gamma(g)=MinGamma+(MaxGamma-MinGamma)*(g-1)/(GammaSteps-1);	%Vector of tension values
d=1:EnergySteps; dE(d)=MindE+(MaxdE-MindE)*(d-1)/(EnergySteps-1);	%Current value of the standard deviation of energy between channels, in kT
d=1:EnergyAreaSteps; dEA(d)=MindEA+(MaxdEA-MindEA)*(d-1)/(EnergyAreaSteps-1);	%Current value of the standard deviation of energy between channels, in kT
r=1:AreaSteps; dA(r)=MindA+(MaxdA-MindA)*(r-1)/(AreaSteps-1);	%Current value of the standard deviation of energy between channels, in kT
dEs=randn([Nchan 1]);	%Generate matrix of random energy deviations
dAs=randn([Nchan 1]);	%Generate matrix of random area deviations
dEAs=randn([Nchan 2]);	%Generate matrix of random energy deviations
a=1:AreaSteps; RngDeltaAs(a)=MinDeltaA+(MaxDeltaA-MinDeltaA)*(a-1)/(AreaSteps-1);	%Array of areas
Nsub=length(DeltaE);	%number of substates


switch CalcMode	%Mode of calculation
	
	case 'dE'	%Activation curves at different energy dispersions. Fixed DeltaE and DeltaA
		ApDeltaE=[]; ApDeltaA=[]; ApGamma05=[];
		for d=1:EnergySteps	%Cycle throught the increasing values of the standard deviation of energy between channels
			if RandomizeEveryStep==1	%Regenerate random numbers at every dispersion value
				dEs=randn([Nchan 1]);	%Generate matrix of random energy deviations
			end
			switch DispMode
				case 'Fraction'
					for s=1:Nsub	%Cycle through substates
						DeltaEs(s,1:Nchan)=(DeltaE(s)*(1+dEs*dE(d)))';	%Current matrix of energies of channel opening kT
					end	%Cycle through substates
				case 'Absolute'
					for s=1:Nsub	%Cycle through substates
						DeltaEs(s,1:Nchan)=(DeltaE(s)+dEs*dE(r))';	%Current matrix of energies of channel opening kT
					end	%Cycle through substates
			end
			for g=1:GammaSteps	%Cycle through the tension steps
				for s=1:Nsub	%Cycle through substates
					Pos(s,1:Nchan)=exp(-DeltaEs(s,:)+(1E-21)*Gamma(g)*DeltaA(s)/kT);	%Matrix of  probabilities to be in the substate at the given value of energy dispersion and tension value for every channel. 1E-21 is conversion factor from (nm^2*dynes/cm) to J
				end	%Cycle through substates
				%Normalize sum of Ps for every channel
				for c=1:Nchan	%Cycle through the channels in patch
					Pos(:,c)=Pos(:,c)/sum(Pos(:,c));
				end		%Cycle through the channels in patch
					
				Po(:,d,g)=mean(Pos,2);	%Average (per patch) probability to be in the certain substate at the given value of energy dispersion and tension value
			end 	%Cycle through the tension steps
		end	%Cycle throught the increasing values of the standard deviation of energy between channels
		
		Pot=Po; Pot(Pot==1)=max(Pot(Pot<1)); Pot(Pot==0)=min(Pot(Pot>0));	%remove values which will give infinity and zeros
		%____ Po/Pc ratio
		for s=2:Nsub	%Cycle through conducting substates
			PoPc(s,:,:)=Pot(s,:,:)./Pot(1,:,:);
		end	%Cycle through conducting substates
		PoPct=PoPc; %PoPct(PoPct>MaxPoPc)=MaxPoPc; PoPct(PoPct<MinPoPc)=MinPoPc;	%remove values which will give infinity and zeros
		
		%***************** Make a linear fit and extract apparent energy and area
		for  r=1:EnergySteps	%Cycle throught the increasing values of the standard deviation of energy between channels
			PointsInRange=find((PoPc(end,r,:)>=MinPoPc)&(PoPc(end,r,:)<=MaxPoPc));	%Select pressure steps fitting into the observable range (by the last state)
			for s=2:Nsub	%Cycle through conducting substates
				v = polyfit(Gamma(PointsInRange),reshape(log(PoPc(s,r,PointsInRange)),1,length(PointsInRange)),1);	%Make a linear fit and extract parameters - ApDeltaE in kT, ApDeltaA in 1/(kT*dynes/cm)
				ApDeltaA(s,r)=v(1);
				ApDeltaE(s,r)=-v(2);
			end	%Cycle through conducting substates
		end	%Cycle throught the increasing values of the standard deviation of energy between channels
		ApGamma05=ApDeltaE./ApDeltaA;
		ApDeltaA=ApDeltaA*kT*(1E21);	%Conversion to nm^2
		
		FileNameOut=[FileName{1},'_dE-sim_',strrep(strrep(datestr(datenum(clock)),' ','_'),':','-')];	%Data output filename 
		if SaveResults	%Option to save results in the file
			FileData=[dE;ApDeltaE]'; save([FileNameOut,'_ApDeltaE-vs-dE.txt'],'FileData','-ascii','-tabs');
			FileData=[dE;ApDeltaA]'; save([FileNameOut,'_ApDeltaA-vs-dE.txt'],'FileData','-ascii','-tabs');
			FileData=[dE;ApGamma05]'; save([FileNameOut,'_ApGamma05-vs-dE.txt'],'FileData','-ascii','-tabs');
		end	%Option to save results in the file
		
		cl_min=2; cl_max=Nsub;	%Min and max values for color index
		%___ Plot DeltaE
 		figure
		hold on
		for s=2:Nsub	%Cycle through substates
			if Nsub>2
				cl=s;	%Current index for color
				plot(dE,ApDeltaE(s,:),'.-','Color', [(1-(cl-cl_min)/(cl_max-cl_min)),  (1-2*abs((cl-cl_min)-(cl_max-cl_min)/2)/(cl_max-cl_min)),  (cl-cl_min)/(cl_max-cl_min)]);
			else
				plot(dE,ApDeltaE(s,:),'k.-');
			end
		end	%Cycle through substates
		switch DispMode
			case 'Fraction'
				xlabel('dE/DeltaE0','Interpreter','none')
			case 'Absolute'
				xlabel('dE, kT','Interpreter','none')
		end
 		ylabel('DeltaE, kT','Interpreter','none')
		set(gca,'XGrid','on');
		set(gca,'YGrid','on');
		hold off
		if SaveImage==1	%save image
			tstr=['print -dpng ''',FileNameOut,'_ApDeltaE-vs-dE.png'''];
			eval(tstr);
		end
		
		%___ Plot DeltaA
 		figure
		hold on
		for s=2:Nsub	%Cycle through substates
			if Nsub>2
				cl=s;	%Current index for color
				plot(dE,ApDeltaA(s,:),'.-','Color', [(1-(cl-cl_min)/(cl_max-cl_min)),  (1-2*abs((cl-cl_min)-(cl_max-cl_min)/2)/(cl_max-cl_min)),  (cl-cl_min)/(cl_max-cl_min)]);
			else
				plot(dE,ApDeltaA(s,:),'k.-');
			end
		end	%Cycle through substates
		switch DispMode
			case 'Fraction'
				xlabel('dE/DeltaE0','Interpreter','none')
			case 'Absolute'
				xlabel('dE, kT','Interpreter','none')
		end
 		ylabel('DeltaA, nm^2','Interpreter','none')
		set(gca,'XGrid','on');
		set(gca,'YGrid','on');
		hold off
		if SaveImage==1	%save image
			tstr=['print -dpng ''',FileNameOut,'_ApDeltaA-vs-dE.png'''];
			eval(tstr);
		end
		
		%___ Plot Gamma05
 		figure
		hold on
		for s=2:Nsub	%Cycle through substates
			if Nsub>2
				cl=s;	%Current index for color
				plot(dE,ApGamma05(s,:),'.-','Color', [(1-(cl-cl_min)/(cl_max-cl_min)),  (1-2*abs((cl-cl_min)-(cl_max-cl_min)/2)/(cl_max-cl_min)),  (cl-cl_min)/(cl_max-cl_min)]);
			else
				plot(dE,ApGamma05(s,:),'k.-');
			end
		end	%Cycle through substates
		switch DispMode
			case 'Fraction'
				xlabel('dE/DeltaE0','Interpreter','none');
			case 'Absolute'
				xlabel('dE, kT','Interpreter','none');
		end
		ylabel('Gamma0.5, dyne/cm','Interpreter','none');
		set(gca,'XGrid','on');
		set(gca,'YGrid','on');
		hold off
		if SaveImage==1	%save image
			tstr=['print -dpng ''',FileNameOut,'_ApGamma05-vs-dE.png'''];
			eval(tstr);
		end
		
		if (EnergySteps<100)	%if plot does not have too many lines
			figure
			hold on
			cl_min=2; cl_max=Nsub;	%Min and max values for color index
			for s=2:Nsub	%Cycle through substates
				if Nsub>2
					cl=s;	%Current index for color
					plot(Gamma,reshape(PoPc(s,:,:),EnergySteps,GammaSteps),'-','Color', [(1-(cl-cl_min)/(cl_max-cl_min)),  (1-2*abs((cl-cl_min)-(cl_max-cl_min)/2)/(cl_max-cl_min)),  (cl-cl_min)/(cl_max-cl_min)]);
				else
					plot(Gamma,reshape(PoPc(s,:,:),EnergySteps,GammaSteps),'k-');
				end
			end	%Cycle through substates
			axis([4 16 1e-8 1e8]);
			set(gca,'YScale','log');
			xlabel('Gamma, dyne/cm','Interpreter','none')
			ylabel('Ps/Pc','Interpreter','none')
			hold on
			plot([4 16],[MinPoPc MinPoPc],'k:')
			plot([4 16],[MaxPoPc MaxPoPc],'k:')
			hold off
			if SaveImage==1	%save image
				tstr=['print -dpng ''',FileNameOut,'_Ps--Pc.png'''];
				eval(tstr);
			end
		end
		
		
		
	case 'dA'	%Activation curves at different Area dispersions. Fixed DeltaE and DeltaA
		ApDeltaE=[]; ApDeltaA=[]; ApGamma05=[];
		for r=1:AreaSteps	%Cycle throught the increasing values of the standard deviation of area between channels
			if RandomizeEveryStep==1	%Regenerate random numbers at every dispersion value
				dAs=randn([Nchan 1]);	%Generate matrix of random area deviations
			end
			switch DispMode
				case 'Fraction'
					for s=1:Nsub	%Cycle through substates
						DeltaAs(s,1:Nchan)=(DeltaA(s)*(1+dAs*dA(r)))';	%Current matrix of energies of channel opening kT
					end	%Cycle through substates
				case 'Absolute'
					for s=1:Nsub	%Cycle through substates
						DeltaAs(s,1:Nchan)=(DeltaA(s)+dAs*dA(r))';	%Current matrix of energies of channel opening kT
					end	%Cycle through substates
			end
			for g=1:GammaSteps	%Cycle through the tension steps
				for s=1:Nsub	%Cycle through substates
					Pos(s,1:Nchan)=exp(-DeltaE(s)+(1E-21)*Gamma(g)*DeltaAs(s,:)/kT);	%Matrix of  probabilities to be in the substate at the given value of area dispersion and tension value for every channel. 1E-21 is conversion factor from (nm^2*dynes/cm) to J
				end	%Cycle through substates
				%Normalize sum of Ps for every channel
				for c=1:Nchan	%Cycle through the channels in patch
					Pos(:,c)=Pos(:,c)/sum(Pos(:,c));
				end		%Cycle through the channels in patch
					
				Po(:,r,g)=mean(Pos,2);	%Average (per patch) probability to be in the certain substate at the given value of energy dispersion and tension value
			end 	%Cycle through the tension steps
		end	%Cycle throught the increasing values of the standard deviation of area between channels
		
		Pot=Po; Pot(Pot==1)=max(Pot(Pot<1)); Pot(Pot==0)=min(Pot(Pot>0));	%remove values which will give infinity and zeros
		%____ Po/Pc ratio
		for s=2:Nsub	%Cycle through conducting substates
			PoPc(s,:,:)=Pot(s,:,:)./Pot(1,:,:);
		end	%Cycle through conducting substates
		PoPct=PoPc; %PoPct(PoPct>MaxPoPc)=MaxPoPc; PoPct(PoPct<MinPoPc)=MinPoPc;	%remove values which will give infinity and zeros
		
		%***************** Make a linear fit and extract apparent energy and area
		for  r=1:AreaSteps	%Cycle throught the increasing values of the standard deviation of energy between channels
			PointsInRange=find((PoPc(end,r,:)>=MinPoPc)&(PoPc(end,r,:)<=MaxPoPc));	%Select pressure steps fitting into the observable range (by the last state)
			for s=2:Nsub	%Cycle through conducting substates
				v = polyfit(Gamma(PointsInRange),reshape(log(PoPc(s,r,PointsInRange)),1,length(PointsInRange)),1);	%Make a linear fit and extract parameters - ApDeltaE in kT, ApDeltaA in 1/(kT*dynes/cm)
				ApDeltaA(s,r)=v(1);
				ApDeltaE(s,r)=-v(2);
			end	%Cycle through conducting substates
		end	%Cycle throught the increasing values of the standard deviation of energy between channels
		ApGamma05=ApDeltaE./ApDeltaA;
		ApDeltaA=ApDeltaA*kT*(1E21);	%Conversion to nm^2
		
		FileNameOut=[FileName{1},'_dA-sim_',strrep(strrep(datestr(datenum(clock)),' ','_'),':','-')];	%Data output filename 
		if SaveResults	%Option to save results in the file
			FileData=[dA;ApDeltaE]'; save([FileNameOut,'_ApDeltaE-vs-dA.txt'],'FileData','-ascii','-tabs');
			FileData=[dA;ApDeltaA]'; save([FileNameOut,'_ApDeltaA-vs-dA.txt'],'FileData','-ascii','-tabs');
			FileData=[dA;ApGamma05]'; save([FileNameOut,'_ApGamma05-vs-dA.txt'],'FileData','-ascii','-tabs');
		end	%Option to save results in the file

		cl_min=2; cl_max=Nsub;	%Min and max values for color index
		%___ Plot DeltaE
 		figure
		hold on
		for s=2:Nsub	%Cycle through substates
			if Nsub>2
				cl=s;	%Current index for color
				plot(dA,ApDeltaE(s,:),'.-','Color', [(1-(cl-cl_min)/(cl_max-cl_min)),  (1-2*abs((cl-cl_min)-(cl_max-cl_min)/2)/(cl_max-cl_min)),  (cl-cl_min)/(cl_max-cl_min)]);
			else
				plot(dA,ApDeltaE(s,:),'k.-');
			end
		end	%Cycle through substates
		switch DispMode
			case 'Fraction'
				xlabel('dA/DeltaA0','Interpreter','none')
			case 'Absolute'
				xlabel('dA, nm^2','Interpreter','none')
		end
 		ylabel('DeltaE, kT','Interpreter','none')
		set(gca,'XGrid','on');
		set(gca,'YGrid','on');
		hold off
		if SaveImage==1	%save image
			tstr=['print -dpng ''',FileNameOut,'_ApDeltaE-vs-dA.png'''];
			eval(tstr);
		end
		
		%___ Plot DeltaA
 		figure
		hold on
		for s=2:Nsub	%Cycle through substates
			if Nsub>2
				cl=s;	%Current index for color
				plot(dA,ApDeltaA(s,:),'.-','Color', [(1-(cl-cl_min)/(cl_max-cl_min)),  (1-2*abs((cl-cl_min)-(cl_max-cl_min)/2)/(cl_max-cl_min)),  (cl-cl_min)/(cl_max-cl_min)]);
			else
				plot(dA,ApDeltaA(s,:),'k.-');
			end
		end	%Cycle through substates
		switch DispMode
			case 'Fraction'
				xlabel('dA/DeltaA0','Interpreter','none')
			case 'Absolute'
				xlabel('dA, nm^2','Interpreter','none')
		end
 		ylabel('DeltaA, nm^2','Interpreter','none')
		set(gca,'XGrid','on');
		set(gca,'YGrid','on');
		hold off
		if SaveImage==1	%save image
			tstr=['print -dpng ''',FileNameOut,'_ApDeltaA-vs-dA.png'''];
			eval(tstr);
		end
		
		%___ Plot Gamma05
 		figure
		hold on
		for s=2:Nsub	%Cycle through substates
			if Nsub>2
				cl=s;	%Current index for color
				plot(dA,ApGamma05(s,:),'.-','Color', [(1-(cl-cl_min)/(cl_max-cl_min)),  (1-2*abs((cl-cl_min)-(cl_max-cl_min)/2)/(cl_max-cl_min)),  (cl-cl_min)/(cl_max-cl_min)]);
			else
				plot(dA,ApGamma05(s,:),'k.-');
			end
		end	%Cycle through substates
		switch DispMode
			case 'Fraction'
				xlabel('dA/DeltaA0','Interpreter','none')
			case 'Absolute'
				xlabel('dA, nm^2','Interpreter','none')
		end
 		ylabel('Gamma0.5, dyne/cm','Interpreter','none')
		set(gca,'XGrid','on');
		set(gca,'YGrid','on');
		hold off
		if SaveImage==1	%save image
			tstr=['print -dpng ''',FileNameOut,'_ApGamma05-vs-dA.png'''];
			eval(tstr);
		end
		
		if (AreaSteps<100)	%if plot does not have too many lines
			figure
			hold on
			cl_min=2; cl_max=Nsub;	%Min and max values for color index
			for s=2:Nsub	%Cycle through substates
				if Nsub>2
					cl=s;	%Current index for color
					plot(Gamma,reshape(PoPc(s,:,:),AreaSteps,GammaSteps),'-','Color', [(1-(cl-cl_min)/(cl_max-cl_min)),  (1-2*abs((cl-cl_min)-(cl_max-cl_min)/2)/(cl_max-cl_min)),  (cl-cl_min)/(cl_max-cl_min)]);
				else
					plot(Gamma,reshape(PoPc(s,:,:),AreaSteps,GammaSteps),'k-');
				end
			end	%Cycle through substates
			axis([4 16 1e-8 1e8]);
			set(gca,'YScale','log');
			xlabel('Gamma, dyne/cm','Interpreter','none')
			ylabel('Ps/Pc','Interpreter','none')
			hold on
			plot([4 16],[MinPoPc MinPoPc],'k:')
			plot([4 16],[MaxPoPc MaxPoPc],'k:')
			hold off
			if SaveImage==1	%save image
				tstr=['print -dpng ''',FileNameOut,'_Ps--Pc.png'''];
				eval(tstr);
			end
		end
		
		
		
	case 'dEA'	%Activation curves at different Area and Energy dispersions. Fixed DeltaE and DeltaA
		ApDeltaE=[]; ApDeltaA=[]; ApGamma05=[];
		for d=1:EnergyAreaSteps	%Cycle throught the increasing values of the standard deviation of energy between channels
			if RandomizeEveryStep==1	%Regenerate random numbers at every dispersion value
				dEAs=randn([Nchan 2]);	%Generate matrix of random energy deviations
			end
			for s=1:Nsub	%Cycle through substates
				DeltaEs(s,1:Nchan)=(DeltaE(s)*(1+dEAs(:,1)*dEA(d)))';	%Current matrix of energies of channel opening kT
				DeltaAs(s,1:Nchan)=(DeltaA(s)*(1+dEAs(:,2)*dEA(d)))';	%Current matrix of energies of channel opening kT
			end	%Cycle through substates
			for g=1:GammaSteps	%Cycle through the tension steps
				for s=1:Nsub	%Cycle through substates
					Pos(s,1:Nchan)=exp(-DeltaEs(s,:)+(1E-21)*Gamma(g)*DeltaAs(s,:)/kT);	%Matrix of  probabilities to be in the substate at the given value of energy and area dispersions and tension value for every channel. 1E-21 is conversion factor from (nm^2*dynes/cm) to J
				end	%Cycle through substates
				%Normalize sum of Ps for every channel
				for c=1:Nchan	%Cycle through the channels in patch
					Pos(:,c)=Pos(:,c)/sum(Pos(:,c));
				end		%Cycle through the channels in patch
					
				Po(:,d,g)=mean(Pos,2);	%Average (per patch) probability to be in the certain substate at the given value of energy dispersion and tension value
			end 	%Cycle through the tension steps
		end	%Cycle throught the increasing values of the standard deviation of energy between channels
		
		Pot=Po; Pot(Pot==1)=max(Pot(Pot<1)); Pot(Pot==0)=min(Pot(Pot>0));	%remove values which will give infinity and zeros
		%____ Po/Pc ratio
		for s=2:Nsub	%Cycle through conducting substates
			PoPc(s,:,:)=Pot(s,:,:)./Pot(1,:,:);
		end	%Cycle through conducting substates
		PoPct=PoPc; %PoPct(PoPct>MaxPoPc)=MaxPoPc; PoPct(PoPct<MinPoPc)=MinPoPc;	%remove values which will give infinity and zeros
		
		%***************** Make a linear fit and extract apparent energy and area
		for  r=1:EnergyAreaSteps	%Cycle throught the increasing values of the standard deviation of energy between channels
			PointsInRange=find((PoPc(end,r,:)>=MinPoPc)&(PoPc(end,r,:)<=MaxPoPc));	%Select pressure steps fitting into the observable range (by the last state)
			for s=2:Nsub	%Cycle through conducting substates
				v = polyfit(Gamma(PointsInRange),reshape(log(PoPc(s,r,PointsInRange)),1,length(PointsInRange)),1);	%Make a linear fit and extract parameters - ApDeltaE in kT, ApDeltaA in 1/(kT*dynes/cm)
				ApDeltaA(s,r)=v(1);
				ApDeltaE(s,r)=-v(2);
			end	%Cycle through conducting substates
		end	%Cycle throught the increasing values of the standard deviation of energy between channels
		ApGamma05=ApDeltaE./ApDeltaA;
		ApDeltaA=ApDeltaA*kT*(1E21);	%Conversion to nm^2
		
		FileNameOut=[FileName{1},'_dEA-sim_',strrep(strrep(datestr(datenum(clock)),' ','_'),':','-')];	%Data output filename 
		if SaveResults	%Option to save results in the file
			FileData=[dEA;ApDeltaE]'; save([FileNameOut,'_ApDeltaE-vs-dEA.txt'],'FileData','-ascii','-tabs');
			FileData=[dEA;ApDeltaA]'; save([FileNameOut,'_ApDeltaA-vs-dEA.txt'],'FileData','-ascii','-tabs');
			FileData=[dEA;ApGamma05]'; save([FileNameOut,'_ApGamma05-vs-dEA.txt'],'FileData','-ascii','-tabs');
		end	%Option to save results in the file
		
		if SaveEndSummary	%Option to save summary with ApDeltaA, ApDeltaE  at the max value of parameter dispersion in the file
			%FileData=[Conductance'; ApDeltaE(:,end)';ApDeltaA(:,end)']'; save([FileNameOut,'_ApPar-vs-dEA.txt'],'FileData','-ascii','-tabs');
			%FileData=[Conductance'; mean(ApDeltaE,2)';mean(ApDeltaA,2)']'; save([FileNameOut,'_ApParMean-vs-dEA.txt'],'FileData','-ascii','-tabs');
			FileData=[Conductance'; mean(ApDeltaE,2)';mean(ApDeltaA,2)';mean(ApGamma05,2)']'; save([FileNameOut,'_ApParMean-vs-dEA.txt'],'FileData','-ascii','-tabs');
		end	%Option to save summary with ApDeltaA, ApDeltaE  at the max value of parameter dispersion in the file
			

		cl_min=2; cl_max=Nsub;	%Min and max values for color index
		%___ Plot DeltaE
 		figure
		hold on
		for s=2:Nsub	%Cycle through substates
			if Nsub>2
				cl=s;	%Current index for color
				plot(dEA,ApDeltaE(s,:),'.-','Color', [(1-(cl-cl_min)/(cl_max-cl_min)),  (1-2*abs((cl-cl_min)-(cl_max-cl_min)/2)/(cl_max-cl_min)),  (cl-cl_min)/(cl_max-cl_min)]);
			else
				plot(dEA,ApDeltaE(s,:),'k.-');
			end
		end	%Cycle through substates
		switch DispMode
			case 'Fraction'
				xlabel('dEA/DeltaEA0','Interpreter','none')
			case 'Absolute'
				xlabel('dEA, kT','Interpreter','none')
		end
 		ylabel('DeltaE, kT','Interpreter','none')
		set(gca,'XGrid','on');
		set(gca,'YGrid','on');
		hold off
		if SaveImage==1	%save image
			tstr=['print -dpng ''',FileNameOut,'_ApDeltaE-vs-dA.png'''];
			eval(tstr);
		end
		
		%___ Plot DeltaA
 		figure
		hold on
		for s=2:Nsub	%Cycle through substates
			if Nsub>2
				cl=s;	%Current index for color
				plot(dEA,ApDeltaA(s,:),'.-','Color', [(1-(cl-cl_min)/(cl_max-cl_min)),  (1-2*abs((cl-cl_min)-(cl_max-cl_min)/2)/(cl_max-cl_min)),  (cl-cl_min)/(cl_max-cl_min)]);
			else
				plot(dEA,ApDeltaA(s,:),'k.-');
			end
		end	%Cycle through substates
		switch DispMode
			case 'Fraction'
				xlabel('dEA/DeltaEA0','Interpreter','none')
			case 'Absolute'
				xlabel('dEA, kT','Interpreter','none')
		end
 		ylabel('DeltaA, nm^2','Interpreter','none')
		set(gca,'XGrid','on');
		set(gca,'YGrid','on');
		hold off
		if SaveImage==1	%save image
			tstr=['print -dpng ''',FileNameOut,'_ApDeltaA-vs-dEA.png'''];
			eval(tstr);
		end
		
		%___ Plot Gamma05
 		figure
		hold on
		for s=2:Nsub	%Cycle through substates
			if Nsub>2
				cl=s;	%Current index for color
				plot(dEA,ApGamma05(s,:),'.-','Color', [(1-(cl-cl_min)/(cl_max-cl_min)),  (1-2*abs((cl-cl_min)-(cl_max-cl_min)/2)/(cl_max-cl_min)),  (cl-cl_min)/(cl_max-cl_min)]);
			else
				plot(dEA,ApGamma05(s,:),'k.-');
			end
		end	%Cycle through substates
		switch DispMode
			case 'Fraction'
				xlabel('dEA/DeltaEA0','Interpreter','none');
			case 'Absolute'
				xlabel('dEA, kT','Interpreter','none');
		end
		ylabel('Gamma0.5, dyne/cm','Interpreter','none');
		set(gca,'XGrid','on');
		set(gca,'YGrid','on');
		hold off
		if SaveImage==1	%save image
			tstr=['print -dpng ''',FileNameOut,'_ApGamma05-vs-dEA.png'''];
			eval(tstr);
		end
		
		if (EnergySteps<100)	%if plot does not have too many lines
			figure
			hold on
			cl_min=2; cl_max=Nsub;	%Min and max values for color index
			for s=2:Nsub	%Cycle through substates
				if Nsub>2
					cl=s;	%Current index for color
					plot(Gamma,reshape(PoPc(s,:,:),EnergySteps,GammaSteps),'-','Color', [(1-(cl-cl_min)/(cl_max-cl_min)),  (1-2*abs((cl-cl_min)-(cl_max-cl_min)/2)/(cl_max-cl_min)),  (cl-cl_min)/(cl_max-cl_min)]);
				else
					plot(Gamma,reshape(PoPc(s,:,:),EnergySteps,GammaSteps),'k-');
				end
			end	%Cycle through substates
			axis([4 16 1e-8 1e8]);
			set(gca,'YScale','log');
			xlabel('Gamma, dyne/cm','Interpreter','none')
			ylabel('Ps/Pc','Interpreter','none')
			hold on
			plot([4 16],[MinPoPc MinPoPc],'k:')
			plot([4 16],[MaxPoPc MaxPoPc],'k:')
			hold off
			if SaveImage==1	%save image
				tstr=['print -dpng ''',FileNameOut,'_Ps--Pc.png'''];
				eval(tstr);
			end
		end
				
end	%Mode of calculation