%rebinhst - function, rebinning histogram into specified bins
function [HstR,BinsXn,MaxsXn,BinsYn,MaxsYn,BinsZn,MaxsZn]=rebinswtchst(Hst,RebTypeX,MinX,StepX,MaxX,...
	BinsX,NormX,NormRelX,NormRelSubX,RebTypeY,MinY,StepY,MaxY,BinsY,NormY,NormRelY,...
	NormRelSubY,RebTypeZ,MinZ,StepZ,MaxZ,BinsZ,NormZ,NormRelZ,NormRelSubZ,NormZN,...
	InterpLevZ,InterpType);
%Outputs:
%HstR -	Rebinned histogram file
%BinsXn -	New X axes bins
%BinsYn -	New Y axes bins
%BinsZn -	New Z axes bins
%MaxsXn -	Maximums vector for the new X axis bins.
%MaxsYn -	Maximums vector for the new Y axis bins.
%MaxsZn -	Maximums vector for the new Z axis bins.

%Inputs:
%Hst - histogram data file
%RebTypeX -	Mode for X axis rebinning: none <1*>, Auto extremum select <5>
%Defined number of steps <2>, new bins width <3>, bins vector <4>, just averaging to the same bins <6>
%MinX -	Minimal X value from edit box
%StepX -	Number of new bins for X axis, averaging length, or new bins vector, depending on RebTypeX
%MaxX -	Maximal X value from edit box
%BinsX -	Old bins vector for X axis
%NormX -	Normalize <1> X values or not <0*> relative to NormRelX value
%NormRelX -	Value for X normalization
%RebTypeY -	Mode for Y axis rebinning: none <1*>, Auto extremum select <2>,
%Defined number of steps <3>, bins vector <4>, just averaging to the same bins <5>
%StepY -	Number of new bins for Y axis, averaging length, or new bins vector, depending on RebTypeY
%BinsY -	Old bins vector for Y axis
%NormZ -	Mode for Z axis values normalization:'Z Absolute' <1*> - no normalization,
%'Z/All pnts' <2> - relative to all points in current X bin,'Z/X pnts' <3>,'Z/Y pnts' <4>
%InterpLevZ -	Treshold level for Z values interpolation, relative to mean value for the axis bin
%InterpType -	Interpolation type between 2 over-treshold lines: 'None' <1*>,'Linear' <2>,'Exponential <3>, 'Enfrcd Linr' <4>, 'Enfrcd Expntl' <5>


BinsXn=[]; BinsYn=[];
MaxsXn=[]; MaxsYn=[];
HstR=Hst;

if NormX
	if (NormRelSubX~=0);	%Substracting NormRelSubX from X axis values 
		BinsX=BinsX-NormRelSubX;
		MinX=MinX-NormRelSubX;
		MaxX=MaxX-NormRelSubX;
	end
	if (NormRelX~=0)%&(NormRelX~=1);	%Normalizing X axis values relative to NormRelX
		NormRelX=NormRelX-NormRelSubX;
		BinsX=BinsX/NormRelX;
		MinX=MinX/NormRelX;
		MaxX=MaxX/NormRelX;
	end
end
if NormY
	if (NormRelSubY~=0);	%Substracting NormRelSubY from Y axis values 
		NormRelY=NormRelY-NormRelSubY;
		BinsY=BinsY-NormRelSubY;
		MinY=MinY-NormRelSubY;
		MaxY=MaxY-NormRelSubY;
	end
	if (NormRelY~=0)%&(NormRelY~=1);	%Normalizing Y axis values relative to NormRelY
		BinsY=BinsY/NormRelY;
		MinY=MinY/NormRelY;
		MaxY=MaxY/NormRelY;
	end
end

ZerX='NX';
%***	Rebinning X axis (current)
switch RebTypeX
case 1
	BinsXn=BinsX;
case 2	%Defined number of steps
	%   BinsXn=max(MinX,BinsX(1)):(BinsX(end)-BinsX(1))/StepX:min(MaxX,BinsX(end));
	BinsXn=MinX:(MaxX-MinX)/StepX:MaxX;
	HstR=distrhst(HstR,BinsX,BinsXn,1,InterpLevZ,InterpType);
case 3	%Defined bin width
	BinsXn=max(MinX,BinsX(1)):StepX:min(MaxX,BinsX(end));
	HstR=distrhst(HstR,BinsX,BinsXn,1,InterpLevZ,InterpType);
case 4	%bins vector
	BinsXn=StepX;
	HstR=distrhst(HstR,BinsX,BinsXn,1,InterpLevZ,InterpType);
case 5	%Auto extremum select
	HstX=sum(HstR,2);	%Total histogram summarized along rows.
	HstX=averhst(HstX,StepX);	%Averaging histogram among +-StepX neighbors
    ExtrFindMethod='MinMax';    %Method of extremums search
	[BinsXn,MaxsXn] =findextrhst(HstX,StepX,BinsX,ExtrFindMethod);	%Finding extremums of histogram,
	%and assigning minimums and boundaries as bins
	HstR=distrhst(HstR,BinsX,BinsXn,1,InterpLevZ,InterpType);
case 6	%just averaging to the same bins 
	HstRn=zeros(size(HstR));
	BinsXn=BinsX;
	for i=1:size(HstR,2)	%cycle by Y
		HstRn(:,i)=[averhst(HstR(:,i),StepX)]';	%Avereging histogram among +-StepX neighbors
	end
	HstR=HstRn;
case 7  %,'Zeroing'
	ZerX='ZX';
	BinsXn=BinsX;
case 8	%Rebinning between the Defined number of maximums
	HstX=sum(HstR,2);	%Total histogram summarized along rows.
    ExtrFindMethod='NumMax';    %Method of extremums search
	[BinsXn,MaxsXn] =findextrhst(HstX,StepX,BinsX,ExtrFindMethod);	%Finding extremums of histogram,
	%and assigning minimums and boundaries as bins
	HstR=distrhst(HstR,BinsX,BinsXn,1,InterpLevZ,InterpType);
end


ZerY='NY';
%***	Rebinning Y axis (pressure)
switch RebTypeY
case 1
	BinsYn=BinsY;
case 2	%Defined number of steps
	%   BinsYn=max(MinY,BinsY(1)):(BinsY(end)-BinsY(1))/StepY:min(MaxY,BinsY(end));
	BinsYn=MinY:(MaxY-MinY)/StepY:MaxY;
	HstR=distrhst(HstR,BinsY,BinsYn,2,InterpLevZ,InterpType);
case 3	%Defined bin width
	BinsYn=max(MinY,BinsY(1)):StepY:min(MaxY,BinsY(end));
	HstR=distrhst(HstR,BinsY,BinsYn,2,InterpLevZ,InterpType);
case 4	%bins vector
	BinsYn=StepY;
	HstR=distrhst(HstR,BinsY,BinsYn,2,InterpLevZ,InterpType);
case 5	%Auto extremum select
	HstY=sum(HstR,1);	%Total histogram summarized along rows.
	HstY=averhst(HstY,StepY);	%Avereging histogram among +-StepY neighbors
    ExtrFindMethod='MinMax';    %Method of extremums search
	[BinsYn,MaxsYn] =findextrhst(HstY,StepY,BinsY,ExtrFindMethod);	%Finding extremums of histogram,
	%and assigning minimums and boundaries as bins
	HstR=distrhst(HstR,BinsY,BinsYn,2,InterpLevZ,InterpType);
case 6	%just averaging to the same bins 
	HstRn=zeros(size(HstR));
	BinsYn=BinsY;
	for i=1:size(HstR,1)	%cycle by X
		HstRn(i,:)=averhst(HstR(i,:),StepY);	%Avereging histogram among +-StepY neighbors
	end
	HstR=HstRn;
case 7  %,'Zeroing'
	ZerY='ZY';
	BinsYn=BinsY;
end

if length(MaxsXn)==0
	for i=1:(length(BinsXn)-1)
		MaxsXn(i)=(BinsXn(i)+BinsXn(i+1))/2;
	end
end
if length(MaxsYn)==0
	for i=1:(length(BinsYn)-1)
		MaxsYn(i)=(BinsYn(i)+BinsYn(i+1))/2;
	end
end


if (RebTypeX==4|RebTypeX==5)	%Bins vector. Ajust points number according to bins length's
	s=(BinsXn(end)-BinsXn(1))/(length(BinsXn)-1);
	for i=1:(length(BinsXn)-1)
		d=(BinsXn(i+1)-BinsXn(i))/s;
		HstR(i,:)=HstR(i,:)/d;
	end
end

if (RebTypeY==4|RebTypeY==5)	%Bins vector. Ajust points number according to bins length's
	s=(BinsYn(end)-BinsYn(1))/(length(BinsYn)-1);
	for i=1:(length(BinsYn)-1)
		d=(BinsYn(i+1)-BinsYn(i))/s;
		HstR(:,i)=HstR(:,i)/d;
	end
end

%ZerZ='NZ';
ZerTot=[ZerX,ZerY];
switch ZerTot
case 'NXNY'
case 'NXZY'
	MinYn=min(find(BinsYn>=MinY));
	MaxYn=max(find(BinsYn<=MaxY))-1;
	HstR(:,MinYn:MaxYn)=0;
case 'ZXNY'
	MinXn=min(find(BinsXn>=MinX));
	MaxXn=max(find(BinsXn<=MaxX))-1;
	HstR(MinXn:MaxXn,:)=0;
case 'ZXZY'
	MinYn=min(find(BinsYn>=MinY));
	MaxYn=max(find(BinsYn<=MaxY))-1;
	MinXn=min(find(BinsXn>=MinX));
	MaxXn=max(find(BinsXn<=MaxX))-1;
	HstR(MinXn:MaxXn,MinYn:MaxYn)=0;
end


%***	Normalizing Z values
switch NormZN	%Mode for Z axis values normalization
case 1	%'Z Absolute' <1*> - no normalization
case 2	%'Z/All pnts'
	HstR=HstR/sum(sum(HstR));
case 3	%'Z/X pnts' 
	HstD=sum(HstR,2); %1-dimensional sum histogram
	InterpLevZ=InterpLevZ*sum(sum(HstR))/length(HstD);	%Interpolation treshold converted into points number
	HstDBelowN=find(HstD<InterpLevZ);
	HstDAboveN=find(HstD>=InterpLevZ);
	for i=1:length(HstD)	%Normalizing lines which are above treshold
		if HstD(i)>=InterpLevZ
			HstR(i,:)=HstR(i,:)/sum(HstR(i,:));
		end
	end
	if InterpType==1	%there is no interpolation - wrong rows are zeroed
		HstR(HstDBelowN,:)=0;
	else %There is some kind of interpolation
		for i=1:length(HstDBelowN)
			MinN=find(HstDAboveN<HstDBelowN(i));
			MaxN=find(HstDAboveN>HstDBelowN(i));
			if length(MinN)>0;	%there is at least 1 normal row before
				MinN=max(MinN);
				if length(MaxN)>0;	%there is at least 1 normal row after
					MaxN=min(MaxN);	%there are two normal rows - before and after
					switch InterpType
					case 2	%Linear
						HstR(HstDBelowN(i),:)=HstR(MinN,:)+(HstR(MaxN,:)-HstR(MinN,:))*...
							(HstDBelowN(i)-MinN)/(MaxN-MinN); 
					case 3	%Exponential
						HstR(HstDBelowN(i),:)=exp(log(HstR(MinN,:))-(log(HstR(MaxN,:))-...
							log(HstR(MinN,:)))*(HstDBelowN(i)-MinN)/(MaxN-MinN)); 
					end
				else
					HstR(HstDBelowN(i),:)=HstR(MinN,:);	%there is  normal row only before
				end
			else
				if length(MaxN)>0;	%there is at least 1 normal row after
					MaxN=min(MaxN);
					HstR(HstDBelowN(i),:)=HstR(MaxN,:);	%there is  normal row only after
				else
					HstR(HstDBelowN(i),:)=0;	%There is no normal rows
				end
			end
		end
	end
case 4	%'Z/Y pnts'
	HstD=sum(HstR,1); %1-dimensional sum histogram
	InterpLevZ=InterpLevZ*sum(sum(HstR))/length(HstD);	%Interpolation treshold converted into points number
	HstDBelowN=find(HstD<InterpLevZ);
	HstDAboveN=find(HstD>=InterpLevZ);
	for i=1:length(HstD)	%Normalizing lines which are above treshold
		if HstD(i)>=InterpLevZ
			HstR(:,i)=HstR(:,i)/sum(HstR(:,i));
		end
	end
	if InterpType==1	%there is no interpolation - wrong rowa are zeroed
		HstR(:,HstDBelowN)=0;
	else %There is some kind of interpolation
		for i=1:length(HstDBelowN)
			MinN=find(HstDAboveN<HstDBelowN(i));
			MaxN=find(HstDAboveN>HstDBelowN(i));
			if length(MinN)>0;	%there is at least 1 normal row before
				MinN=max(MinN);
				if length(MaxN)>0;	%there is at least 1 normal line after
					MaxN=min(MaxN);	%there are two normal line - before and after
					switch InterpType
					case 2	%Linear
						HstR(:,HstDBelowN(i))=HstR(:,HstDAboveN(MinN))+(HstR(:,MaxN)-HstR(:,HstDAboveN(MinN)))*...
							(HstDBelowN(i)-HstDAboveN(MinN))/(HstDAboveN(MaxN)-HstDAboveN(MinN)); 
					case 3	%Exponential
						HstR(:,HstDBelowN(i))=exp(log(HstR(:,HstDAboveN(MinN)))+(log(HstR(:,HstDAboveN(MaxN)))-log(HstR(:,HstDAboveN(MinN))))*...
							(HstDBelowN(i)-HstDAboveN(MinN))/(HstDAboveN(MaxN)-HstDAboveN(MinN))); 
					end
				else
					HstR(:,HstDBelowN(i))=HstR(:,HstDAboveN(MinN));	%there is  normal line only before
				end
			else
				if length(MaxN)>0;	%there is at least 1 normal line after
					MaxN=min(MaxN);
					HstR(:,HstDBelowN(i))=HstR(:,HstDAboveN(MaxN));	%there is  normal line only after
				else
					HstR(:,HstDBelowN(i))=0;	%There is no normal lines
				end
			end
		end
	end
	%case 7  %,'Zeroing'
	%ZerZ='ZZ';
case 5	%'Z/(Bin area)'
	for i=1:size(HstR,1)
		for j=1:size(HstR,2)
			HstR(i,j)=HstR(i,j)/((BinsXn(i+1)-BinsXn(i))*(BinsYn(i+1)-BinsYn(i)));	%Divides each bin value to the area of this bin - this is to convert histogram to the probability density function for the unequel bins 
		end
	end
end

SndN(3);

function HstR=distrhst(Hst,BinsX,BinsXn,Dimn,InterpLevZ,InterpType)	%Redistributing histogram counts in X axis
%Outputs:
%HstR -	Rebinned histogram file

%Inputs:
%Hst - histogram data file
%BinsX -	Old bins vector for X axis
%BinsXn -	New X axes bins
%Dimn -	Dimension number for rebinning: X <1*>, or Y <2>.
if Dimn==1	%Rebinning X axis
	HstR=zeros(length(BinsXn)-1,size(Hst,2));
else	%Rebinning Y axis
	HstR=zeros(size(Hst,1),length(BinsXn)-1);
end
if ((InterpType==4)|(InterpType==5))&(length(BinsXn)/length(BinsX)>=InterpLevZ)	%"Enforced linear" rebin mode and increased number of new bins
	i=1:(length(BinsX)-1);
	BinsXC=(BinsX(i)+BinsX(i+1))/2;	%Medium points vector of old bins
	i=1:(length(BinsXn)-1);
	BinsXnC=(BinsXn(i)+BinsXn(i+1))/2;	%Medium points vector of new bins
	
	if (InterpType==5)	%Enforced exponential interpolation
		HstL=log10(loghst(Hst));
	else	%Linear interpolation
		HstL=Hst;
	end
	if Dimn==1	%Rebinning X axis
		for k=1:size(Hst,2)
			%	    HstR(:,k)=interp1(BinsXC,HstL(:,k),BinsXnC');	%new interpolated values
			HstR(:,k)=interp1AGB(BinsXC,HstL(:,k),BinsXnC');	%new interpolated values - no NaNs
			HstR((BinsXnC<BinsX(1))|(BinsXnC>BinsX(end)),k)=NaN;	%Outrange new bins
		end
	else	%Rebinning Y axis
		for k=1:size(Hst,1)
			%	    HstR(k,:)=interp1(BinsXC,HstL(k,:),BinsXnC);	%new interpolated values
			HstR(k,:)=interp1AGB(BinsXC,HstL(k,:),BinsXnC);	%new interpolated values - no NaNs
			HstR(k,(BinsXnC<BinsX(1))|(BinsXnC>BinsX(end)))=NaN;	%Outrange new bins
		end
	end
	
	if (InterpType==5)	%Enforced exponential interpolation
		HstR(isnan(HstR))=min(min(HstR));	%Replacing NaN values (new bins which are out of the old bins range) with zeros
		HstR=unloghst(10.^(HstR));
	else	%Linear interpolation
		HstR(isnan(HstR))=0;	%Replacing NaN values (new bins which are out of the old bins range) with zeros
	end
	
else	%Usual rebin
	for i=1:(length(BinsX)-1)	%cicle through the old bins
		NMinXn=max(find(BinsXn<=BinsX(i))); %Maximal new bin boundary, lower than current old lower
		if length(NMinXn)==0;	%No new bin boundary, lower than current old low
			NMinXn=min(find(BinsXn<BinsX(i+1)));	%Closest new bin boundary, lower than current old higher
		end
		
		NMaxXn=min(find(BinsXn>=BinsX(i+1))); %Minimal new bin boundary, higher than current old higher
		if length(NMaxXn)==0;	%No new bin boundary, higher than current old high
			NMaxXn=max(find(BinsXn>BinsX(i)));	%Closest new bin boundary, higher than current old higher
		end
		
		if length(NMinXn)~=0&length(NMaxXn)~=0	%There some new bins intersecting with current old
			for k=NMinXn:(NMaxXn-1)
				prp=min(BinsXn(k+1),BinsX(i+1))-max(BinsXn(k),BinsX(i));   %Proportion of old bin which overlap current new bin, relative to the length of the whole old bin
				prp=prp/(BinsXn(k+1)-BinsXn(k));
				%prp=prp/((BinsX(i+1)-BinsX(i));
				if Dimn==1	%Rebinning X axis
					HstR(k,:)=HstR(k,:)+Hst(i,:)*prp;	%Adding proportional part of old counts from old bin to the new one
				else	%Rebinning Y axis
					HstR(:,k)=HstR(:,k)+Hst(:,i)*prp;	%Adding proportional part of old counts from old bin to the new one
				end
			end
		end
	end
end


