%================ %Deviation estimation function for genetic algorithm
function f=tst_dev_max(x) %Deviation estimation function for genetic algorithm
global HstT_L HstN_L par_valRange_L InterpType_L Smoothing_L SMethod_L ecount_L h_L BinsT_L BinsT_Lp
par_val=x;
[tdev,HstT_Lr]=tst_dev(HstT_L,HstN_L,par_val,par_valRange_L,InterpType_L,Smoothing_L,SMethod_L);
%Input - vector of independent parameters values
f=1/max(tdev,1e-200);
   ecount_L%!

if floor(length(ecount_L)/10)==length(ecount_L)/10
    close(h_L)
    h_L=figure;%!
    BinsT_Lp=(BinsT_L(1:(end-1))+BinsT_L(2:end))/2;   %!Bins for plotting
    plot(BinsT_Lp,HstT_L,'b');%!
    hold on%!
    plot(BinsT_Lp,exp(par_val),'r');%!
    [t,HstT_Lr]=tst_dev(HstT_L,HstN_L,par_val,par_valRange_L,InterpType_L,Smoothing_L,SMethod_L);%!
    t%!Deviation
    plot(BinsT_Lp,HstT_Lr,'g');%!
    hold off%!
    set(gca,'YScale','log');
    pause(0.3)%!
%     trcsave('TempSystemTrace',HstT_Lr,BinsT_L);
%     trcsave('TempSystemTraceDen',par_val,BinsT_L);
end


%============	Criterion function estimation subfunction
function [tdev,HstT_Lr]=tst_dev(HstT_L,HstN_L,par_val,par_valRange_L,InterpType_L,Smoothing_L,SMethod_L)
%Output:
%tdev   - integral deviation value

%Inputs:
%HstT_L	- Fitted trace histogram
%HstN_L	- Noise histogram
%par_val    - parameters' values vector
%par_valRange_L	-Range of including in consideration for each Noise-Bins pair
%InterpType_L 	- Type of estimation for the criterion function - <1> 'Linear', <2*> 'Linear Wtd', <3> 'Log', <4> 'Log Wtd'
%Smoothing_L	- Smooshing coefficient. <0> - no smoothing
%SMethod_L	- Smoothing_L method: <1> - neighbors ratio log dispersion; <2> - -logarithm maximization
global ecount_L
ecount_L=ecount_L+1;    %Function evaluations counter
HstT_Lr=zeros(1,length(par_val)); %Empty reconstructed histogram


for i=1:length(par_val)   %Cycle for filling up reconstructed histogram
    %for j=0:(par_valRange_L(4,i)-par_valRange_L(2,i))

    %Add next scaled noise bins set to the reconstructed histogram
    HstT_Lr(par_valRange_L(2,i):par_valRange_L(4,i))=HstT_Lr(par_valRange_L(2,i):par_valRange_L(4,i))+...
        HstN_L(par_valRange_L(1,i):par_valRange_L(3,i))*exp(par_val(i)); 
end

switch InterpType_L
case 1  %Linear
    tdev=(sum((HstT_L-HstT_Lr).^2)/length(HstT_L))^0.5;
    tdev=tdev*NonSmooth(par_val,Smoothing_L,SMethod_L);
case 2  %Linear Wtd
    Wht=mean([HstT_L;HstT_Lr]);    %weihgting vector
%     Wht(Wht==0)=1;  %uniting zero elements
    tdev=(sum(((HstT_L-HstT_Lr).^2)./Wht)/length(HstT_L))^0.5;
    tdev=tdev*NonSmooth(par_val,Smoothing_L,SMethod_L);
case 3  %Log
%     HstT_Lr(HstT_Lr==0)=min(HstT_Lr(HstT_Lr>0))/3;  %Replacing zero elements
    tdev=(sum(log(HstT_L./HstT_Lr).^2)/length(HstT_L))^0.5;
    tdev=tdev*NonSmooth(par_val,Smoothing_L,SMethod_L);
case 4  %Log Wtd
%     HstT_Lr(HstT_Lr==0)=min(HstT_Lr(HstT_Lr>0))/3;  %Replacing zero elements
    Wht=geomean([HstT_L;HstT_Lr]);    %weihgting vector
    tdev=(sum((log(HstT_L./HstT_Lr).^2).*(Wht.^0.5))/length(HstT_L))^0.5;
    tdev=tdev*NonSmooth(par_val,Smoothing_L,SMethod_L);
end


%================	Smoothing_L deviation function
function NSm=NonSmooth(par_val,Smoothing_L,SMethod_L)

%Output:
%NSm - Non-smoothness coefficient

%Inputs:
%par_val	- Parameters vector to be smoothed
%Smoothing_L	- Smoothing_L value
%SMethod_L	- Smoothing_L estimation method

if Smoothing_L ~=0	%Some smoothing
    switch SMethod_L
    case 1	%neighbors ratio log dispersion
        NSm=log(par_val(1:(end-1))./par_val(2:end));	%Non-smoothness coefficient
        NSm=(1+std(NSm))^Smoothing_L;
    case 2	%-logarithm maximization
        NSm=(1+1/mean(abs(log(par_val)).^Smoothing_L)).^Smoothing_L;
    case 3	% <3> - combined 1 and 2
        NSm=log(par_val(1:(end-1))./par_val(2:end));	%Non-smoothness coefficient
        NSm=(1+std(NSm))^Smoothing_L;
        NSm2=(1+1/mean(abs(log(par_val)).^Smoothing_L)).^Smoothing_L;
        NSm=NSm*NSm2;
    case 4	%Piecewise rate smoothing
        par_valT=log(par_val);
        Smoothing_L=min(Smoothing_L,floor(length(par_val)/2-1));
        NSm=par_valT((1+Smoothing_L):(length(par_valT)-Smoothing_L));
        for i=1:Smoothing_L
            NSm=NSm+par_valT((1+Smoothing_L-i):(length(par_valT)-Smoothing_L-i))+par_valT((1+Smoothing_L+i):(length(par_valT)-Smoothing_L+i));
        end
        NSm=NSm/(2*Smoothing_L+1);	%This is geometrical mean between N=Smoothing_L different values
        NSm=abs(par_valT((1+Smoothing_L):(length(par_valT)-Smoothing_L))-NSm);
        NSm=(1+sum(NSm)/length(NSm)*Smoothing_L)^Smoothing_L;
        % 	NSm=log(par_val(1:(end-1))./par_val(2:end));	%Non-smoothness coefficient
        % 	TStd=0;
        % 	for i=1:length(NSm)
        % 	    TStd=TStd+std(NSm(max(1,(i-Smoothing_L)):min(length(NSm),(i+Smoothing_L))));
        % 	end
        % 	NSm=(1+TStd)^Smoothing_L;
    case 5  %Parameters std maximization
        NSm=log(par_val);
        NSm=(1+std(NSm))^(-1*Smoothing_L);
    case 6  %Acceleration minimization
        par_valT=log(par_val);
        NSm=par_valT(1:(end-2))+par_valT(3:end)-2*par_valT(2:(end-1));	%Non-smoothness coefficient
        NSm=(1+std(NSm))^Smoothing_L;
    end
else
    NSm=1;
end

