%twodimhist - calculates 2D histogram of provided input matrixes or file data
function [Hst,BinsX,BinsY]=twodimhist(Readfile,XY,AutoX,MinX,MaxX,StepX,RebTypeX,AutoY,MinY,MaxY,StepY,RebTypeY,FileType,...
	TimeRng,TimeRngType,TimeRngProf,NormZN,InterpLevZ,SaveCntrlTrace,h_UseAdvCond,h_AdvCond);
%Outputs:
%Hst -	Output historgam matrix.
%BinsX -	Calculated or provided X bins' boundaries vector.
%BinsY -	Calculated or provided Y bins' boundaries vector.

%Inputs:
%Readfile -	Flag for reading X and Y data from input vectors <1>, from single file <2*>.
%XY -	Vector of initial X and Y data (2xn), or filename for input data file for X and Y values, depending on "Readfile" value.
%AutoX -	Use absolute (full data range) Minimum and Maximum to range bins <1*>, or use user-defined values <0>.
%AutoY -	Use absolute (full data range) Minimum and Maximum to range bins <1*>, or use user-defined values <0>.
%RebTypeX -	Defines whether to use predefined steps number <1*>, bin width <2>, or user-defined bin boundaries vector <3>.
%RebTypeY -	Defines whether to use predefined steps number <1*>, bin width <2>, or user-defined bin boundaries vector <3>.
%MinX -	Minimal X range value.
%StepX -	X range steps number <1*>, X range bin width <2>, or
%user-defined bin boundaries vector <3> (depending on "StepsBinVect" value).
%MaxX -	Maximal X range value.
%MinY -	Minimal Y range value.
%StepY -	Y range steps number <1*>, X range bin width <2>, or
%user-defined bin boundaries vector <3> (depending on "StepsBinVect" value).
%MaxY -	Maximal Y range value.
%FileType -	Axon Text File (.ATF) <1*> with 2 channels, c	Axon Text File (.ATF) <2> with 1 channels, Text file (.TXT) <3>, or Axon binary file (.ABF) <4>.
%TimeRng -	Range radius +- this number of points to be included in consideration
%TimeRngType -	Type of weighting coefficient. 'pike only' <1>,'mean(|Rate|)/|mean(Rate)|' <2>,'|mean(Pnt Acclr)|' <3>;
%TimeRngProf -	Profile for including points in consideration: 'Eqvl' Equal amplitude for all points considered <1>,
%'Ln Dn' linear decreaze from 1 in the middle up to zero at the point next after the range <2>
%NormZN -	Type of Z axis normalization: 'Z Absolute' <1>,'Z/(All pnts)' <2>,'Z/(X pnts)' <3>,'Z/(Y pnts)' <4>,'Z*(X wght)' <5>,'Z*(Y wght)' <6>
%InterpLevZ -	Degree of Z axis normalization at weighting
%SaveCntrlTrace	- Mode of saving control trace{'Don''t save', 'Save included points', 'Save mark of inclusion','Save included point and mark of inclusion'}
%h_UseAdvCond	- %Mode of combining of several advanced conditions - {'Don''t use advanced conditions', 'Combine advanced conditions as "AND"','Combine advanced conditions as "OR"', 'Combine advanced conditions as "~(AND)"', 'Combine advanced conditions as "~(OR)"'});	
%h_AdvCond	- Structure with all the parameters for advanced conditions 1, 2, and 3:
% h_AdvCond(1).Cond=1;	%{'(No Condition)','pike','m(|R|)/|m(R)|','|m(A)|','|m(A)|/|V|','1/sd','s.p.*dV/(V+Vmn)','s.p.*mx(Va,Vb)',...
% %'s.p.*mx(Va,Vb)/(Vmn+mn(Va,Vb))','a/(aa+ab+amn','1/sd(V)','pk tll','pk wd'});	%Type of condition
% h_AdvCond(1).Opt=1;	%{'(Default Options)'});	%Main option of condition
% h_AdvCond(1).Box=1;	%{'Equal','/\ - shaped','Normal'});	%Shape of analysis box - equal number of any included points or not
% h_AdvCond(1).BoxUnits=1;	%{'Neighbors','Absolute'});	%Units of box size
% h_AdvCond(1).BoxSize=1;	%Size of the box in time to include into analysis- in +- neighbors or in +1 s
% h_AdvCond(1).CondWeight=1;	%Condition weight coefficient. The more is it the more sharply condition is applied 
% h_AdvCond(1).RangeType=1;	%{'(None)','Min<W<Max','Min<=W<=Max','Min<W','Min<=W','W<Max','W<=Max','~(Min<W<Max)','~(Min<=W<=Max)'});	%Range type for the calculated coefficient to fit into to be included into the histogram
% h_AdvCond(1).RangeUnits=1;	%{'Neighbors','Absolute','Mean','St. Dev.'});	%Units of box size
% h_AdvCond(1).Min=0;	%Minimal value of the range
% h_AdvCond(1).Max=1;	%Maximal value of the range



global VminW VmaxW
OutCntrData=[]; %Initialize output array with control trace data
ReadStep=200000;	%Step for data reading from HDD

%***	Defining Minimum and Maximum to range bins

if Readfile==2	%reading X and Y data from single file
	
	DataFile=XY;	%Data filename
	fidDF=fopen(DataFile);	%Opens trace file
	switch FileType
	case 1	%Axon Text File (.ATF) with 2 channels
		for i=1:10	%Reading text file header
			DataNotes{i}=fgetl(fidDF);
		end
        % Correct header according to acquisition mode
        switch DataNotes{3}
        case {'"AcquisitionMode=Gap Free"'}
        case {'"AcquisitionMode=Episodic Stimulation"'}
            for i=7:9
                DataNotes{i}=DataNotes{i+1};
            end
            DataNotes{10}=fgetl(fidDF);
        end
	case 2	%Axon Text File (.ATF) with 1 channel
		for i=1:10	%Reading text file header
			DataNotes{i}=fgetl(fidDF);
		end
        % Correct header according to acquisition mode
        switch DataNotes{3}
        case {'"AcquisitionMode=Gap Free"'}
        case {'"AcquisitionMode=Episodic Stimulation"'}
            for i=7:9
                DataNotes{i}=DataNotes{i+1};
            end
            DataNotes{10}=fgetl(fidDF);
        end
	case 3	%Text File (.txt)
	end
	
	
	if ((AutoX==1)|(AutoY==1))	%Use absolute (full data range) Minimum and Maximum to range bins
		
		
		switch FileType
		case 1	%Axon Text File (.ATF) with 2 channels
			[t]=sscanf(DataNotes{5},'%*6c %f %*1c %f');
			if (AutoX==1); MaxX=t(1); end
			if (AutoY==1); MaxY=t(2); end
			[t]=sscanf(DataNotes{6},'%*9c %f %*1c %f');
			if (AutoX==1); MinX=t(1); end
			if (AutoY==1); MinY=t(2); end
			
			if SaveCntrlTrace>1	%Control trace will be saved
				FileNameOut=[DataFile,'_cntr.'];	%Data output filename
				%---------- Open output trace control file for writing. Data part of the file.
				FileNameOut=[FileNameOut,'atf'];	%Data output filename
				fidOF=fopen(FileNameOut,'w');	%Opens trace file for writing
				fidHF=fopen([FileNameOut,'.tmp'],'w');	%Header file for writing
				MaxI=0;	MinI=0;	%Initialize minimum and maximum values of inclusion field
			end	%Control trace will be saved
			
		case 2	%Axon Text File (.ATF) with 1 channel
			if (AutoX==1);
				MaxX=sscanf(DataNotes{5},'%*6c %f');
				MinX=sscanf(DataNotes{6},'%*9c %f');
			end
			
			if (AutoY==1);
				XY=[0;0]; %Empty Data matrix
				t=0;	%Flag for the first step of extremum search
				Read=2*ReadStep;
				while Read>=2*ReadStep	%If the last time complete ReadStep length was read
					[XY,Read]=fscanf(fidDF,'%g %g',[2 ReadStep]);
					if Read~=0
						XY([1 2],:)=XY([2 1],:);	%Swapping time and current
						if t==0	%the first step of extremum search
							MinXY=min(XY,[],2);
							MaxXY=max(XY,[],2);
							t=1;
						else
							MinXY=min(MinXY,min(XY,[],2));
							MaxXY=max(MaxXY,max(XY,[],2));
						end
						SndN(1);
					end
				end
				MinY=MinXY(2); MaxY=MaxXY(2); 	%Time in swapped array
			end
			
			if SaveCntrlTrace>1	%Control trace will be saved
				FileNameOut=[DataFile,'_cntr.'];	%Data output filename
				%---------- Open output trace control file for writing. Data part of the file.
				FileNameOut=[FileNameOut,'atf'];	%Data output filename
				fidOF=fopen(FileNameOut,'w');	%Opens trace file for writing
				fidHF=fopen([FileNameOut,'.tmp'],'w');	%Header file for writing
				MaxI=0;	MinI=0;	%Initialize minimum and maximum values of inclusion field
			end	%Control trace will be saved
			
		case 3	%Text File (.txt)
			XY=[0;0]; %Empty Data matrix
			t=0;	%Flag for the first step of extremum search
			Read=2*ReadStep;
			while Read>=2*ReadStep	%If the last time complete ReadStep length was read
				[XY,Read]=fscanf(fidDF,'%g %g',[2 ReadStep]);
				if Read~=0
					if t==0	%the first step of extremum search
						MinXY=min(XY,[],2);
						MaxXY=max(XY,[],2);
						t=1;
					else
						MinXY=min(MinXY,min(XY,[],2));
						MaxXY=max(MaxXY,max(XY,[],2));
					end
					SndN(1);
				end
			end
			if (AutoX==1); MinX=MinXY(1); MaxX=MaxXY(1); end
			if (AutoY==1); MinY=MinXY(2); MaxY=MaxXY(2); end
			
			if SaveCntrlTrace>1	%Control trace will be saved
				FileNameOut=[DataFile,'_cntr.'];	%Data output filename
				%---------- Open output trace control file for writing. Data part of the file.
				FileNameOut=[FileNameOut,'txt'];	%Data output filename
				fidOF=fopen(FileNameOut,'w');	%Opens trace file for writing
				MaxI=0;	MinI=0;	%Initialize minimum and maximum values of inclusion field
			end	%Control trace will be saved
			
		end
	end
	
	
else	%reading X and Y data from input vectors
	if ((AutoX==1)|(AutoY==1))	%Use absolute (full data range) Minimum and Maximum to range bins
		MinXY=min(XY,[],2);
		MaxXY=max(XY,[],2);
		if (AutoX==1); MinX=MinXY(1); MaxX=MaxXY(1); end
		if (AutoY==1); MinY=MinXY(2); MaxY=MaxXY(2); end
	end
	if SaveCntrlTrace>1	%Control trace will be saved
		FileNameOut=['Data-Vectors_',strrep(strrep(datestr(datenum(clock)),' ','_'),':','-'),'_cntr.'];	%Data output filename
		%---------- Open output trace control file for writing. Data part of the file.
		FileNameOut=[FileNameOut,'txt'];	%Data output filename
		fidOF=fopen(FileNameOut,'w');	%Opens trace file for writing
		MaxI=0;	MinI=0;	%Initialize minimum and maximum values of inclusion field
	end	%Control trace will be saved
	
end



%***	Creating bins' boundaries vectors

switch RebTypeX	%Bins creation mode parameter
case 1	%predefined steps number
	BinsX=MinX:(MaxX-MinX)/StepX:MaxX;
case 2	%bin width 
	BinsX=MinX:StepX:(MaxX+StepX);
case 3	%user-defined bin boundaries vector
	BinsX=StepX;
end
switch RebTypeY	%Bins creation mode parameter
case 1	%predefined steps number
	BinsY=MinY:(MaxY-MinY)/StepY:MaxY;
case 2	%bin width 
	BinsY=MinY:StepY:(MaxY+StepY);
case 3	%user-defined bin boundaries vector
	BinsY=StepY;
end

Hst=zeros((length(BinsX)-1),(length(BinsY)-1));	%Initializing Histogram file

%----Finding minimum and maximum changes in amplitudes (and rates)
VmaxW=(BinsX(end)-BinsX(1));
VminW=VmaxW/length(BinsX);
FirstTimeRead=1;	%Flag that This is the first time data read from the file
LastTimeRead=0;	%Flag that This is the last time data read from the file
%******************************* Distributing data among bins

if Readfile==2	%reading X and Y data from single file
	status = fseek(fidDF,0,'bof');
	XY=[0;0]; %Empty Data matrix
	%Step=1;	%Flag for the first step in file reading
	XYadd=[];	%Addition for the averaging
	OutCntrDataadd=[]; 	%Addition to the control output file for the averaging
	TimeXYadd=[]; 	%Addition to the control output file time for the averaging
	OutCntrData=[]; 	%Initialisation of the the control output file
	TimeXY=0; 	%Initialisation of the the control output file
	
	switch FileType
	case 1	%Axon Text File (.ATF) with 2 channels
		for i=1:10	%Reading text file header
			t=fgetl(fidDF);
		end
        % Correct header according to acquisition mode
        switch DataNotes{3}
        case {'"AcquisitionMode=Gap Free"'}
        case {'"AcquisitionMode=Episodic Stimulation"'}
            t=fgetl(fidDF);
        end
		Read=3*ReadStep;
		while Read>=3*ReadStep	%If the last time complete ReadStep length was read
			[XY,Read]=fscanf(fidDF,'%g %g %g',[3 ReadStep]);
			if Read~=0	%something was read
				TimeXY=XY(1,:);	%Time span read this time
				XY=XY(2:3,:);	%Data fields
				
				if Read<3*ReadStep	%The last time data are read
					LastTimeRead=1;	%Flag that This is the last time data read from the file
				end	%The last time data are read
				if FirstTimeRead	%This is the first time data read from the file
					%----- Block for calculation of maximal time range of all the ranges of all the advanced conditions
					TimeRng=[];
					for tm=1:length(h_AdvCond);	%Cycle through the advanced conditions
						if h_AdvCond(tm).Cond>1	%This condition is used
							if h_AdvCond(tm).BoxUnits==1	%box size in neighbors
								h_AdvCond(tm).BoxSize=round(h_AdvCond(tm).BoxSize);
							else	%box size in seconds
								h_AdvCond(tm).BoxSize=round(h_AdvCond(tm).BoxSize/(TimeXY(2)-TimeXY(1)));	%Time range for this condition
							end	%box size in neighbors
							TimeRng(end+1)=h_AdvCond(tm).BoxSize;	%Time range for this condition
						end	%This condition is used
					end	%Cycle through the advanced conditions
					TimeRng=round(max(TimeRng));	%Determining maximal time range of all the ranges of all the advanced conditions
				end	%This is the first time data read from the file
				
				switch NormZN	%Pre-binning data matrix conversion
				case {5, 6}	%Weighting Z
					if SaveCntrlTrace>1	%Control trace will be saved
						OutCntrData=XY;	%Initial value for the control data array
						OutCntrData(2,:)=1;	%Mark for inclusion of all the points
						[OutCntrData,OutCntrDataadd]=elongate(OutCntrData,OutCntrDataadd,FirstTimeRead,TimeRng);
						[TimeXY,TimeXYadd]=elongate(TimeXY,TimeXYadd,FirstTimeRead,TimeRng);
					end
					[XY,XYadd]=elongate(XY,XYadd,FirstTimeRead,TimeRng);
				end
				[Hst,OutCntrData]=distribute(XY,Hst,BinsX,BinsY,TimeRng,TimeRngType,TimeRngProf,NormZN,InterpLevZ,OutCntrData,h_UseAdvCond,h_AdvCond,FirstTimeRead,LastTimeRead);	%Filling histogram file
				
				if SaveCntrlTrace>1	%Control trace will be saved
					Write_OutCntrData=[TimeXY;XY;OutCntrData];	%Forming control data piece to write
					MaxI=max([MaxI,OutCntrData(2,:)]);	MinI=min([MinI,OutCntrData(2,:)]);	%Updating minimum and maximum values of inclusion field
					
					%---------Determining bins analysis range
					switch NormZN
					case {1,2,3,4,7} 
					case {5,6}
						Write_OutCntrData(:,(1+TimeRng):(end-TimeRng));
					end
					
					switch SaveCntrlTrace	%Mode of saving control trace
					case 1	%'Don''t save'
					case 2	%'Save included points'
						fprintf(fidOF,'%f\t %g\t %g\t %g\n',Write_OutCntrData([1:4],:));
					case 3	%'Save mark of inclusion'
						fprintf(fidOF,'%f\t %g\t %g\t %g\n',Write_OutCntrData([1:3,5],:));
					case 4	%'Save included point and mark of inclusion'
						fprintf(fidOF,'%f\t %g\t %g\t %g\t %g\n',Write_OutCntrData);
					end	%Mode of saving control trace
				end	%Control trace will be saved
				if FirstTimeRead	%This is the first time data read from the file
					FirstTimeRead=0;	%Flag that This is the first time data read from the file
				end	%This is the first time data read from the file
			end	%something was read
		end	%If the last time complete ReadStep length was read
		
	case 2	%Axon Text File (.ATF) with 1 channel
		for i=1:10	%Reading text file header
			t=fgetl(fidDF);
		end
        % Correct header according to acquisition mode
        switch DataNotes{3}
        case {'"AcquisitionMode=Gap Free"'}
        case {'"AcquisitionMode=Episodic Stimulation"'}
            t=fgetl(fidDF);
        end
		Read=2*ReadStep;
		while Read>=2*ReadStep	%If the last time complete ReadStep length was read
			[XY,Read]=fscanf(fidDF,'%g %g',[2 ReadStep]);
			if Read~=0	%something was read
				TimeXY=XY(1,:);	%Time span read this time
				XY([1 2],:)=XY([2 1],:);	%Swapping time and current
				
				if Read<2*ReadStep	%The last time data are read
					LastTimeRead=1;	%Flag that This is the last time data read from the file
				end	%The last time data are read
				if FirstTimeRead	%This is the first time data read from the file
					%----- Block for calculation of maximal time range of all the ranges of all the advanced conditions
					TimeRng=[];
					for tm=1:length(h_AdvCond);	%Cycle through the advanced conditions
						if h_AdvCond(tm).Cond>1	%This condition is used
							if h_AdvCond(tm).BoxUnits==1	%box size in neighbors
								h_AdvCond(tm).BoxSize=round(h_AdvCond(tm).BoxSize);
							else	%box size in seconds
								h_AdvCond(tm).BoxSize=round(h_AdvCond(tm).BoxSize/(TimeXY(2)-TimeXY(1)));	%Time range for this condition
							end	%box size in neighbors
							TimeRng(end+1)=h_AdvCond(tm).BoxSize;	%Time range for this condition
						end	%This condition is used
					end	%Cycle through the advanced conditions
					TimeRng=round(max(TimeRng));	%Determining maximal time range of all the ranges of all the advanced conditions
					if isempty(TimeRng);TimeRng=0;end
				end	%This is the first time data read from the file
				
				switch NormZN	%Pre-binning data matrix conversion
				case {5, 6}	%Weighting Z
					if SaveCntrlTrace>1	%Control trace will be saved
						OutCntrData=XY;	%Initial value for the control data array
						OutCntrData(2,:)=1;	%Mark for inclusion of all the points
						[OutCntrData,OutCntrDataadd]=elongate(OutCntrData,OutCntrDataadd,FirstTimeRead,TimeRng);
						[TimeXY,TimeXYadd]=elongate(TimeXY,TimeXYadd,FirstTimeRead,TimeRng);
					end
					[XY,XYadd]=elongate(XY,XYadd,FirstTimeRead,TimeRng);
				end
				[Hst,OutCntrData]=distribute(XY,Hst,BinsX,BinsY,TimeRng,TimeRngType,TimeRngProf,NormZN,InterpLevZ,OutCntrData,h_UseAdvCond,h_AdvCond,FirstTimeRead,LastTimeRead);	%Filling histogram file
				
				if SaveCntrlTrace>1	%Control trace will be saved
					Write_OutCntrData=[TimeXY;XY(1,:);OutCntrData];	%Forming control data piece to write
					MaxI=max([MaxI,OutCntrData(2,:)]);	MinI=min([MinI,OutCntrData(2,:)]);	%Updating minimum and maximum values of inclusion field
					
					%---------Determining bins analysis range
					switch NormZN
					case {1,2,3,4,7} 
					case {5,6}
						Write_OutCntrData=Write_OutCntrData(:,(1+TimeRng):(end-TimeRng));
					end
					
					switch SaveCntrlTrace	%Mode of saving control trace
					case 1	%'Don''t save'
					case 2	%'Save included points'
						fprintf(fidOF,'%f\t %g\t %g\n',Write_OutCntrData([1:3],:));
					case 3	%'Save mark of inclusion'
						fprintf(fidOF,'%f\t %g\t %g\n',Write_OutCntrData([1:2,4],:));
					case 4	%'Save included point and mark of inclusion'
						fprintf(fidOF,'%f\t %g\t %g\t %g\n',Write_OutCntrData);
					end	%Mode of saving control trace
				end	%Control trace will be saved
				if FirstTimeRead	%This is the first time data read from the file
					FirstTimeRead=0;	%Flag that This is the first time data read from the file
				end	%This is the first time data read from the file
			end	%something was read
		end	%If the last time complete ReadStep length was read
		
	case 3	%Text File (.txt)
		Read=2*ReadStep;
		while Read>=2*ReadStep	%If the last time complete ReadStep length was read
			[XY,Read]=fscanf(fidDF,'%g %g',[2 ReadStep]);
			if Read~=0	%something was read
				TimeXY=TimeXY(end)+1:length(XY(1,:));	%Time span read this time
				
				if Read<2*ReadStep	%The last time data are read
					LastTimeRead=1;	%Flag that This is the last time data read from the file
				end	%The last time data are read
				if FirstTimeRead	%This is the first time data read from the file
					%----- Block for calculation of maximal time range of all the ranges of all the advanced conditions
					TimeRng=[];
					for tm=1:length(h_AdvCond);	%Cycle through the advanced conditions
						if h_AdvCond(tm).Cond>1	%This condition is used
							if h_AdvCond(tm).BoxUnits==1	%box size in neighbors
								h_AdvCond(tm).BoxSize=round(h_AdvCond(tm).BoxSize);
							else	%box size in seconds
								h_AdvCond(tm).BoxSize=round(h_AdvCond(tm).BoxSize/(TimeXY(2)-TimeXY(1)));	%Time range for this condition
							end	%box size in neighbors
							TimeRng(end+1)=h_AdvCond(tm).BoxSize;	%Time range for this condition
						end	%This condition is used
					end	%Cycle through the advanced conditions
					TimeRng=round(max(TimeRng));	%Determining maximal time range of all the ranges of all the advanced conditions
				end	%This is the first time data read from the file
				
				switch NormZN	%Pre-binning data matrix conversion
				case {5, 6}	%Weighting Z
					if SaveCntrlTrace>1	%Control trace will be saved
						OutCntrData=XY;	%Initial value for the control data array
						OutCntrData(2,:)=1;	%Mark for inclusion of all the points
						[OutCntrData,OutCntrDataadd]=elongate(OutCntrData,OutCntrDataadd,FirstTimeRead,TimeRng);
						[TimeXY,TimeXYadd]=elongate(TimeXY,TimeXYadd,FirstTimeRead,TimeRng);
					end
					[XY,XYadd]=elongate(XY,XYadd,FirstTimeRead,TimeRng);
				end
				[Hst,OutCntrData]=distribute(XY,Hst,BinsX,BinsY,TimeRng,TimeRngType,TimeRngProf,NormZN,InterpLevZ,OutCntrData,h_UseAdvCond,h_AdvCond,FirstTimeRead,LastTimeRead);	%Filling histogram file
				
				if SaveCntrlTrace>1	%Control trace will be saved
					Write_OutCntrData=[TimeXY;XY;OutCntrData];	%Forming control data piece to write
					MaxI=max([MaxI,OutCntrData(2,:)]);	MinI=min([MinI,OutCntrData(2,:)]);	%Updating minimum and maximum values of inclusion field
					
					%---------Determining bins analysis range
					switch NormZN
					case {1,2,3,4,7} 
					case {5,6}
						Write_OutCntrData(:,(1+TimeRng):(end-TimeRng));
					end
					
					switch SaveCntrlTrace	%Mode of saving control trace
					case 1	%'Don''t save'
					case 2	%'Save included points'
						fprintf(fidOF,'%f\t %g\t %g\t %g\n',Write_OutCntrData([1:4],:));
					case 3	%'Save mark of inclusion'
						fprintf(fidOF,'%f\t %g\t %g\t %g\n',Write_OutCntrData([1:3,5],:));
					case 4	%'Save included point and mark of inclusion'
						fprintf(fidOF,'%f\t %g\t %g\t %g\t %g\n',Write_OutCntrData);
					end	%Mode of saving control trace
				end	%Control trace will be saved
				if FirstTimeRead	%This is the first time data read from the file
					FirstTimeRead=0;	%Flag that This is the first time data read from the file
				end	%This is the first time data read from the file
			end	%something was read
		end	%If the last time complete ReadStep length was read
		
	end %FileType
	
else	%reading X and Y data from input vectors
	[Hst,OutCntrData]=distribute(XY,Hst,BinsX,BinsY,TimeRng,TimeRngType,TimeRngProf,NormZN,InterpLevZ,OutCntrData,h_UseAdvCond,h_AdvCond,FirstTimeRead,LastTimeRead);	%Filling histogram file
end


%******************************* Corrects non-uniform bins width

if RebTypeX==3	%Bins vector
	s=(BinsX(end)-BinsX(1))/(length(BinsX)-1);
	for i=1:(length(BinsX)-1)
		d=(BinsX(i+1)-BinsX(i))/s;
		Hst(i,:)=Hst(i,:)/d;
	end
end

if RebTypeY==3	%Bins vector
	s=(BinsY(end)-BinsY(1))/(length(BinsY)-1);
	for i=1:(length(BinsY)-1)
		d=(BinsY(i+1)-BinsY(i))/s;
		Hst(:,i)=Hst(:,i)/d;
	end
end

fclose(fidDF);	%Closes trace file
if SaveCntrlTrace>1	%Control trace will be saved
	MaxI=MaxI+0.05*(MaxI-MinI);	%Wider boundaries 5% for better viewing in Clampfit
	MinI=MinI-0.05*(MaxI-MinI);	%Wider boundaries 5% for better viewing in Clampfit
end	%Control trace will be saved
%*********************** finish writing output control trace file
if SaveCntrlTrace>1	%Control trace will be saved
	switch FileType
	case 1	%Axon Text File (.ATF) with 2 channels
		switch SaveCntrlTrace	%Mode of saving control trace
		case 1	%'Don''t save'
		case 2	%'Save included points'
			%Update extremums' values
			DataNotes{5}=[sprintf('%s','"YTop='), sprintf('%f',MaxX), sprintf('%s',','), sprintf('%f',MaxY), sprintf('%s',','), sprintf('%f',MaxX), sprintf('%s','"')];
			DataNotes{6}=[sprintf('%s','"YBottom='), sprintf('%f',MinX), sprintf('%s',','), sprintf('%f',MinY),sprintf('%s',','), sprintf('%f',MinX), sprintf('%s','"')];
			DataNotes{8}=[DataNotes{8}(1:(end-1)),sprintf('%s',',Ipatch_Included"')];
			DataNotes{9}=[DataNotes{9},sprintf('%s\t',''),sprintf('%s','"Ipatch_Included"')];
			DataNotes{10}=[DataNotes{10},sprintf('%s\t',''),sprintf('%s','"Trace #1 (pA)"')];
		case 3	%'Save mark of inclusion'
			%Update extremums' values
			DataNotes{5}=[sprintf('%s','"YTop='), sprintf('%f',MaxX), sprintf('%s',','), sprintf('%f',MaxY), sprintf('%s',','), sprintf('%f',MaxI), sprintf('%s','"')];
			DataNotes{6}=[sprintf('%s','"YBottom='), sprintf('%f',MinX), sprintf('%s',','), sprintf('%f',MinY), sprintf('%s',','), sprintf('%f',MinI), sprintf('%s','"')];
			DataNotes{8}=[DataNotes{8}(1:(end-1)),sprintf('%s',',Ipatch_Included,Inclusion_Coefficient"')];
			DataNotes{9}=[DataNotes{9},sprintf('%s\t',''),sprintf('%s','"Inclusion_Coefficient"')];
			DataNotes{10}=[DataNotes{10},sprintf('%s\t',''),sprintf('%s','"Trace #1 (Dimensionless)"')];
		case 4	%'Save included point and mark of inclusion'
			%Update extremums' values
			DataNotes{5}=[sprintf('%s','"YTop='), sprintf('%f',MaxX), sprintf('%s',','), sprintf('%f',MaxY), sprintf('%s',','), sprintf('%f',MaxX), sprintf('%s',','), sprintf('%f',MaxI), sprintf('%s','"')];
			DataNotes{6}=[sprintf('%s','"YBottom='), sprintf('%f',MinX), sprintf('%s',','), sprintf('%f',MinY),sprintf('%s',','), sprintf('%f',MinX),sprintf('%s',','), sprintf('%f',MinI), sprintf('%s','"')];
			DataNotes{8}=[DataNotes{8}(1:(end-1)),sprintf('%s',',Ipatch_Included,Inclusion_Coefficient"')];
			DataNotes{9}=[DataNotes{9},sprintf('%s\t',''),sprintf('%s\t','"Ipatch_Included"'),sprintf('%s','"Inclusion_Coefficient"')];
			DataNotes{10}=[DataNotes{10},sprintf('%s\t',''),sprintf('%s\t','"Trace #1 (pA)"'),sprintf('%s','"Trace #1 (Dimensionless)"')];
		end	%Mode of saving control trace
		
		
		for i=1:10	%ReWriting text file header with the updated extremums' values
			Lines=fprintf(fidHF,'%s\n',DataNotes{i});	%print 1 line with line terminators to the file
		end
		fclose(fidOF);	%Closes Data output file
		fclose(fidHF);	%Closes Header output file
		CommandString=['!copy "',FileNameOut,'.tmp" + "',FileNameOut,'" tmpfile.tmp'];
		eval(CommandString);
		CommandString=['!copy tmpfile.tmp "',FileNameOut,'"'];
		eval(CommandString);
		delete('tmpfile.tmp');
		delete([FileNameOut,'.tmp']);
	case 2	%Axon Text File (.ATF) with 1 channel
		switch SaveCntrlTrace	%Mode of saving control trace
		case 1	%'Don''t save'
		case 2	%'Save included points'
			%Update extremums' values
			DataNotes{5}=[sprintf('%s','"YTop='), sprintf('%f',MaxX), sprintf('%s',','), sprintf('%f',MaxX), sprintf('%s','"')];
			DataNotes{6}=[sprintf('%s','"YBottom='), sprintf('%f',MinX),sprintf('%s',','), sprintf('%f',MinX), sprintf('%s','"')];
			DataNotes{8}=[DataNotes{8}(1:(end-1)),sprintf('%s',',Ipatch_Included"')];
			DataNotes{9}=[DataNotes{9},sprintf('%s\t',''),sprintf('%s','"Ipatch_Included"')];
			DataNotes{10}=[DataNotes{10},sprintf('%s\t',''),sprintf('%s','"Trace #1 (pA)"')];
		case 3	%'Save mark of inclusion'
			%Update extremums' values
			DataNotes{5}=[sprintf('%s','"YTop='), sprintf('%f',MaxX), sprintf('%s',','), sprintf('%f',MaxI), sprintf('%s','"')];
			DataNotes{6}=[sprintf('%s','"YBottom='), sprintf('%f',MinX), sprintf('%s',','), sprintf('%f',MinI), sprintf('%s','"')];
			DataNotes{8}=[DataNotes{8}(1:(end-1)),sprintf('%s',',Ipatch_Included,Inclusion_Coefficient"')];
			DataNotes{9}=[DataNotes{9},sprintf('%s\t',''),sprintf('%s','"Inclusion_Coefficient"')];
			DataNotes{10}=[DataNotes{10},sprintf('%s\t',''),sprintf('%s','"Trace #1 (Dimensionless)"')];
		case 4	%'Save included point and mark of inclusion'
			%Update extremums' values
			DataNotes{5}=[sprintf('%s','"YTop='), sprintf('%f',MaxX), sprintf('%s',','), sprintf('%f',MaxX), sprintf('%s',','), sprintf('%f',MaxI), sprintf('%s','"')];
			DataNotes{6}=[sprintf('%s','"YBottom='), sprintf('%f',MinX),sprintf('%s',','), sprintf('%f',MinX),sprintf('%s',','), sprintf('%f',MinI), sprintf('%s','"')];
			DataNotes{8}=[DataNotes{8}(1:(end-1)),sprintf('%s',',Ipatch_Included,Inclusion_Coefficient"')];
			DataNotes{9}=[DataNotes{9},sprintf('%s\t',''),sprintf('%s\t','"Ipatch_Included"'),sprintf('%s','"Inclusion_Coefficient"')];
			DataNotes{10}=[DataNotes{10},sprintf('%s\t',''),sprintf('%s\t','"Trace #1 (pA)"'),sprintf('%s','"Trace #1 (Dimensionless)"')];
		end	%Mode of saving control trace
		
		
		for i=1:10	%ReWriting text file header with the updated extremums' values
			Lines=fprintf(fidHF,'%s\n',DataNotes{i});	%print 1 line with line terminators to the file
		end
		fclose(fidOF);	%Closes Data output file
		fclose(fidHF);	%Closes Header output file
		CommandString=['!copy "',FileNameOut,'.tmp" + "',FileNameOut,'" tmpfile.tmp'];
		eval(CommandString);
		CommandString=['!copy tmpfile.tmp "',FileNameOut,'"'];
		eval(CommandString);
		delete('tmpfile.tmp');
		delete([FileNameOut,'.tmp']);
	case 3	%Text File (.txt)
		fclose(fidOF);	%Closes Data output file
	end
	
end 	%Control trace will be saved

SndN(2);



%***************************** Functions
function [Hst,OutCntrData]=distribute(XY,Hst,BinsX,BinsY,TimeRng,TimeRngType,TimeRngProf,NormZN,InterpLevZ,OutCntrData,h_UseAdvCond,h_AdvCond,FirstTimeRead,LastTimeRead)
%distribute - this function distributes points from XY matrix into Hst matrix
%(adds new counts to values, xeisting in Hst), according to beans vectors
global EnblSnd VminW VmaxW
%Output:
%Hst -	Output historgam matrix.
%OutCntrData	- Control output trace file

%Inputs:
%XY - 	Data matrix.
%Hst -	Input historgam matrix.
%BinsX -	Calculated or provided X bins' boundaries vector.
%BinsY -	Calculated or provided Y bins' boundaries vector.
%TimeRng -	Range radius +- this number of points to be included in consideration
%TimeRngType -	Type of weighting coefficient. 'pike only' <1>,'mean(|Rate|)/|mean(Rate)|' <2>,'|mean(Pnt Acclr)|' <3>;
%TimeRngProf -	Profile for including points in consideration: 'Eqvl' Equal amplitude for all points considered <1>,
%'Ln Dn' linear decreaze from 1 in the middle up to zero at the point next after the range <2>
%NormZN -	Type of Z axis normalization: 'Z Absolute' <1>,'Z/(All pnts)' <2>,'Z/(X pnts)' <3>,'Z/(Y pnts)' <4>,'Z*(X wght)' <5>,'Z*(Y wght)' <6>
%InterpLevZ -	Degree of Z axis normalization at weighting
%OutCntrData	- Control output trace file
%h_AdvCond	- Structure with all the parameters for advanced conditions 1, 2, and 3:
% h_AdvCond(1).Cond=1;	%{'(No Condition)','pike','m(|R|)/|m(R)|','|m(A)|','|m(A)|/|V|','1/sd','s.p.*dV/(V+Vmn)','s.p.*mx(Va,Vb)',...
% %'s.p.*mx(Va,Vb)/(Vmn+mn(Va,Vb))','a/(aa+ab+amn','1/sd(V)','pk tll','pk wd'});	%Type of condition
% h_AdvCond(1).Opt=1;	%{'(Default Options)'});	%Main option of condition
% h_AdvCond(1).Box=1;	%{'Equal','/\ - shaped','Normal'});	%Shape of analysis box - equal number of any included points or not
% h_AdvCond(1).BoxUnits=1;	%{'Neighbors','Absolute'});	%Units of box size
% h_AdvCond(1).BoxSize=1;	%Size of the box in time to include into analysis- in +- neighbors or in +1 s
% h_AdvCond(1).CondWeight=1;	%Condition weight coefficient. The more is it the more sharply condition is applied 
% h_AdvCond(1).RangeType=1;	%{'(None)','Min<W<Max','Min<=W<=Max','Min<W','Min<=W','W<Max','W<=Max','~(Min<W<Max)','~(Min<=W<=Max)'});	%Range type for the calculated coefficient to fit into to be included into the histogram
% h_AdvCond(1).RangeUnits=1;	%{'Neighbors','Absolute','Mean','St. Dev.'});	%Units of box size
% h_AdvCond(1).Min=0;	%Minimal value of the range
% h_AdvCond(1).Max=1;	%Maximal value of the range
%FirstTimeRead	- flag for presence of the file beginning in the piece
%LastTimeRead	- flag for presence of the file end in the piece

SizeX=size(Hst,1); SizeY=size(Hst,2);	%Sizes of hystogram file in X and Y directions

PointX=fix(SizeX/2); PointY=fix(SizeY/2);	%Initial positions of latest bin coordinates


%---------Determining bins analysis range
switch NormZN
case {1,2,3,4,7} 
	BegCycle=1;
	EndCycle=size(XY,2);	%Length of XY data matrix
case {5,6}
	BegCycle=1+TimeRng;
	EndCycle=size(XY,2)-TimeRng;	%Length of XY data matrix
	if FirstTimeRead	%flag for presence of the file beginning in the piece
		OutCntrData(:,1:TimeRng)=0;	%These points are not included
	end	%flag for presence of the file beginning in the piece
	if LastTimeRead	%flag for presence of the file end in the piece
		OutCntrData(:,(end-TimeRng+1):end)=0;	%These points are not included
	end	%flag for presence of the file end in the piece
end

for i=BegCycle:EndCycle	%Cycle through XY data matrix
	
	%** X binning
	if XY(1,i)<BinsX(PointX+1)	%Moving down through the bins
		while PointX>0	%we are above the lowest bin boundary
			if XY(1,i)>=BinsX(PointX)	%fit in the current bin
				break
			else
				PointX=PointX-1;	%1 step down
			end
		end
	else	%Moving up through the bins
		% 		PointX=PointX+1;	%1 step up
		while PointX<=SizeX	%we are below the topmost bin boundary
			if XY(1,i)<BinsX(PointX+1)	%fit in the current bin
				break
			else
				PointX=PointX+1;	%1 step up
			end
		end
	end
	
	%** Y binning
	if XY(2,i)<BinsY(PointY)	%Moving down through the bins
		while PointY>0	%we are above the lowest bin boundary
			if XY(2,i)>=BinsY(PointY)	%fit in the current bin
				break
			else
				PointY=PointY-1;	%1 step down
			end
		end
	else	%Moving up through the bins
		% 		PointY=PointY+1;	%1 step up
		while PointY<=SizeY	%we are below the topmost bin boundary
			if XY(2,i)<BinsY(PointY+1)	%fit in the current bin
				break
			else
				PointY=PointY+1;	%1 step up
			end
		end
	end
	
	%** Adding 1 count to histogram bin
	if (PointX>0)&(PointY>0)&(PointX<=SizeX)&(PointY<=SizeY)	%Point coordinates are within hisogram matrix range
		Weight=1;	%Initial weight
		switch NormZN	%Type of Z axis normalization: 'Z Absolute' <1>,'Z/(All pnts)' <2>,'Z/(X pnts)' <3>,'Z/(Y pnts)' <4>,'Z*(X wght)' <5>,'Z*(Y wght)' <6>
		case {1,2,3,4,7}
		case 5	%X weighting (current)
			%----------- Weighting value
			Weight=[];	%Initial weight
			for cn=1:length(h_AdvCond)	%Cycle through the conditions
				if h_AdvCond(cn).Cond>1	%This condition is used
					switch h_AdvCond(cn).Cond	%Type of weighting coefficient.
					case 1	%No condition
					case 2	%pike	->	'pike  (By the mean rates before and after point)'
						Weight(end+1)=1;	%Initial current condition weight
						NormVect=diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)));	%Rate vector for normalization
						switch h_AdvCond(cn).Box	%Profile for including points in consideration: 
						case 1	%'Eqvl' Equal amplitude for all points considered <1>,
							MeanRateLeft=mean(NormVect(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=mean(NormVect((h_AdvCond(cn).BoxSize+1):end));	%Preliminary normalization coefficient. Mean rate.
						case 2	%'Ln Dn' linear decreaze from 1 in the middle up to zero at the point next after the range <2>
							for tt=1:h_AdvCond(cn).BoxSize
								NormVect(tt)=NormVect(tt)*tt;
								NormVect(end-tt+1)=NormVect(end-tt+1)*tt;
							end
							MeanRateLeft=sum(NormVect(1:h_AdvCond(cn).BoxSize))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=sum(NormVect((h_AdvCond(cn).BoxSize+1):end))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
						end
						
						%---- options block
						switch h_AdvCond(cn).Opt	%Main option of condition
						case 1	%Up or Down
							if (MeanRateLeft>0&MeanRateRight>0)|(MeanRateLeft<0&MeanRateRight<0)	%Pike
								Weight(end)=0;
							end
						case 2	%Up
							if ~(MeanRateLeft>0&MeanRateRight<0)
								Weight(end)=0;
							end
						case 3	%Down
							if ~(MeanRateLeft<0&MeanRateRight>0)
								Weight(end)=0;
							end
						end 
					case 3	%'mean(|Rate|)/|mean(Rate)|' ->	'mean(|Rate|)/|mean(Rate)|  (Noisy regions)'
						Weight(end+1)=1;	%Initial current condition weight
						NormVect=diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)));	%Rate vector for normalization
						switch h_AdvCond(cn).Box	%Profile for including points in consideration: 
						case 1	%'Eqvl' Equal amplitude for all points considered <1>,
							MeanRate=mean(NormVect);	%Preliminary normalization coefficient. Mean rate.
							MeanRateAbs=mean(abs(NormVect));	%Preliminary normalization coefficient. Mean absolute rate.
						case 2	%'Ln Dn' linear decreaze from 1 in the middle up to zero at the point next after the range <2>
							for tt=1:h_AdvCond(cn).BoxSize
								NormVect(tt)=NormVect(tt)*tt;
								NormVect(end-tt+1)=NormVect(end-tt+1)*tt;
							end
							MeanRate=sum(NormVect)/(2*sum(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
							MeanRateAbs=sum(abs(NormVect))/(2*sum(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
						end
						Weight(end)=Weight(end)*(MeanRateAbs/(VminW+abs(MeanRate)))^h_AdvCond(cn).CondWeight;
					case 4	%'|mean(Pnt Acclr)|'	->	'|mean(Rate_after)-mean(Rate_before)|  (Mean acceleration)'
						Weight(end+1)=1;	%Initial current condition weight
						NormVect=diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)));	%Rate vector for normalization
						switch h_AdvCond(cn).Box	%Profile for including points in consideration: 
						case 1	%'Eqvl' Equal amplitude for all points considered <1>,
							MeanRateLeft=mean(NormVect(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=mean(NormVect((h_AdvCond(cn).BoxSize+1):end));	%Preliminary normalization coefficient. Mean rate.
						case 2	%'Ln Dn' linear decreaze from 1 in the middle up to zero at the point next after the range <2>
							for tt=1:h_AdvCond(cn).BoxSize
								NormVect(tt)=NormVect(tt)*tt;
								NormVect(end-tt+1)=NormVect(end-tt+1)*tt;
							end
							MeanRateLeft=sum(NormVect(1:h_AdvCond(cn).BoxSize))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=sum(NormVect((h_AdvCond(cn).BoxSize+1):end))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
						end
						Weight(end)=Weight(end)*abs(MeanRateLeft-MeanRateRight)^h_AdvCond(cn).CondWeight;
					case 5	%'|m(A)|/|V|'	->	'|mean(Rate_after)-mean(Rate_before)|/|mean(Rate)|  (Acceleration of pike type)'
						Weight(end+1)=1;	%Initial current condition weight
						NormVect=diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)));	%Rate vector for normalization
						switch h_AdvCond(cn).Box	%Profile for including points in consideration: 
						case 1	%'Eqvl' Equal amplitude for all points considered <1>,
							MeanRateLeft=mean(NormVect(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=mean(NormVect((h_AdvCond(cn).BoxSize+1):end));	%Preliminary normalization coefficient. Mean rate.
							MeanRate=mean(NormVect);	%Preliminary normalization coefficient. Mean rate.
						case 2	%'Ln Dn' linear decreaze from 1 in the middle up to zero at the point next after the range <2>
							for tt=1:h_AdvCond(cn).BoxSize
								NormVect(tt)=NormVect(tt)*tt;
								NormVect(end-tt+1)=NormVect(end-tt+1)*tt;
							end
							MeanRateLeft=sum(NormVect(1:h_AdvCond(cn).BoxSize))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=sum(NormVect((h_AdvCond(cn).BoxSize+1):end))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
							MeanRate=sum(NormVect)/(2*sum(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
						end
						Weight(end)=Weight(end)*(abs(MeanRateLeft-MeanRateRight)/(VminW+abs(MeanRate)))^h_AdvCond(cn).CondWeight;
					case 6	%'1/sd'	->	'1/Standard_deviation (Low noise regions)'
						Weight(end+1)=1;	%Initial current condition weight
						NormVect=XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize));	%Rate vector for normalization
						Weight(end)=Weight(end)*std(NormVect)^(-h_AdvCond(cn).CondWeight);
					case 7	%'s.p.*dV/(V+Vmn)'	->	'pike & mean(|Rate|)/|mean(Rate)|  (Pike in noisy region)'
						Weight(end+1)=1;	%Initial current condition weight
						NormVect=diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)));	%Rate vector for normalization
						switch h_AdvCond(cn).Box	%Profile for including points in consideration: 
						case 1	%'Eqvl' Equal amplitude for all points considered <1>,
							MeanRateLeft=mean(NormVect(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=mean(NormVect((h_AdvCond(cn).BoxSize+1):end));	%Preliminary normalization coefficient. Mean rate.
							MeanRate=mean(NormVect);	%Preliminary normalization coefficient. Mean rate.
							MeanRateAbs=mean(abs(NormVect));	%Preliminary normalization coefficient. Mean absolute rate.
						case 2	%'Ln Dn' linear decreaze from 1 in the middle up to zero at the point next after the range <2>
							for tt=1:h_AdvCond(cn).BoxSize
								NormVect(tt)=NormVect(tt)*tt;
								NormVect(end-tt+1)=NormVect(end-tt+1)*tt;
							end
							MeanRateLeft=sum(NormVect(1:h_AdvCond(cn).BoxSize))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=sum(NormVect((h_AdvCond(cn).BoxSize+1):end))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
							MeanRate=sum(NormVect)/(2*sum(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
							MeanRateAbs=sum(abs(NormVect))/(2*sum(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
						end
						if MeanRateLeft*MeanRateRight>0
							Weight(end)=0;
						else
							Weight(end)=Weight(end)*(MeanRateAbs/(VminW+abs(MeanRate)))^h_AdvCond(cn).CondWeight;
						end
					case 8	%'s.p.*mx(Va,Vb)'	->	'pike & max(|mean(Rate_before)|,|mean(Rate_after)|)  (Pike near high rate region)'
						Weight(end+1)=1;	%Initial current condition weight
						NormVect=diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)));	%Rate vector for normalization
						switch h_AdvCond(cn).Box	%Profile for including points in consideration: 
						case 1	%'Eqvl' Equal amplitude for all points considered <1>,
							MeanRateLeft=mean(NormVect(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=mean(NormVect((h_AdvCond(cn).BoxSize+1):end));	%Preliminary normalization coefficient. Mean rate.
						case 2	%'Ln Dn' linear decreaze from 1 in the middle up to zero at the point next after the range <2>
							for tt=1:h_AdvCond(cn).BoxSize
								NormVect(tt)=NormVect(tt)*tt;
								NormVect(end-tt+1)=NormVect(end-tt+1)*tt;
							end
							MeanRateLeft=sum(NormVect(1:h_AdvCond(cn).BoxSize))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=sum(NormVect((h_AdvCond(cn).BoxSize+1):end))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
						end
						if MeanRateLeft*MeanRateRight>0
							Weight(end)=0;
						else
							Weight(end)=Weight(end)*(max(abs(MeanRateLeft),abs(MeanRateRight)))^h_AdvCond(cn).CondWeight;
						end
					case 9	%'s.p.*mx(Va,Vb)/(Vmn+mn(Va,Vb))'	->	'pike & max(|mean(Rate_before)|,|mean(Rate_after)|)/min(|mean(Rate_before)|,|mean(Rate_after)|)  (pike near high step)'
						Weight(end+1)=1;	%Initial current condition weight
						NormVect=diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)));	%Rate vector for normalization
						switch h_AdvCond(cn).Box	%Profile for including points in consideration: 
						case 1	%'Eqvl' Equal amplitude for all points considered <1>,
							MeanRateLeft=mean(NormVect(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=mean(NormVect((h_AdvCond(cn).BoxSize+1):end));	%Preliminary normalization coefficient. Mean rate.
						case 2	%'Ln Dn' linear decreaze from 1 in the middle up to zero at the point next after the range <2>
							for tt=1:h_AdvCond(cn).BoxSize
								NormVect(tt)=NormVect(tt)*tt;
								NormVect(end-tt+1)=NormVect(end-tt+1)*tt;
							end
							MeanRateLeft=sum(NormVect(1:h_AdvCond(cn).BoxSize))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=sum(NormVect((h_AdvCond(cn).BoxSize+1):end))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
						end
						if MeanRateLeft*MeanRateRight>0
							Weight(end)=0;
						else
							Weight(end)=Weight(end)*(max(abs(MeanRateLeft),abs(MeanRateRight))/(VminW+min(abs(MeanRateLeft),abs(MeanRateRight))))^h_AdvCond(cn).CondWeight;
						end
					case 10	%'a/(aa+ab+amn)'	->	'|mean(Rate_after)-mean(Rate_before)|/(|mean(Acclr_after)|+|mean(Acclr_before)|)  (Angle between stable rate regions)'
						Weight(end+1)=1;	%Initial current condition weight
						NormVect=diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)));	%Rate vector for normalization
						AccVect=diff(NormVect);	%Accelerations vector for normalization
						switch h_AdvCond(cn).Box	%Profile for including points in consideration: 
						case 1	%'Eqvl' Equal amplitude for all points considered <1>,
							MeanRateLeft=mean(NormVect(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=mean(NormVect((h_AdvCond(cn).BoxSize+1):end));	%Preliminary normalization coefficient. Mean Acceleration.
							%MeanRate=mean(NormVect);	%Preliminary normalization coefficient. Mean Acceleration.
							
							MeanAccLeft=mean(AccVect(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
							MeanAccRight=mean(AccVect(h_AdvCond(cn).BoxSize:end));	%Preliminary normalization coefficient. Mean rate.
							
						case 2	%'Ln Dn' linear decreaze from 1 in the middle up to zero at the point next after the range <2>
							for tt=1:h_AdvCond(cn).BoxSize
								NormVect(tt)=NormVect(tt)*tt;
								NormVect(end-tt+1)=NormVect(end-tt+1)*tt;
							end
							MeanRateLeft=sum(NormVect(1:h_AdvCond(cn).BoxSize))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
							MeanRateRight=sum(NormVect((h_AdvCond(cn).BoxSize+1):end))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
							%MeanRate=sum(NormVect)/(2*sum(1:h_AdvCond(cn).BoxSize));	%Preliminary normalization coefficient. Mean rate.
							
							MeanAccLeft=mean(AccVect(1:h_AdvCond(cn).BoxSize))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
							MeanAccRight=mean(AccVect(h_AdvCond(cn).BoxSize:end))/sum(1:h_AdvCond(cn).BoxSize);	%Preliminary normalization coefficient. Mean rate.
						end
						Weight(end)=Weight(end)*(abs(MeanRateLeft-MeanRateRight)/(VminW+abs(MeanAccLeft)+abs(MeanAccRight)))^h_AdvCond(cn).CondWeight;
					case 11	%'1/sd(V)'	->	'1/Standard_deviation(Rate)  (Linear regions)'
						Weight(end+1)=1;	%Initial current condition weight
						NormVect=diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)));	%Rate vector for normalization
						Weight(end)=Weight(end)*std(NormVect)^(h_AdvCond(cn).CondWeight);
					case 12	%'pk tll'	->	'max(Up_in-row,Down_in-row)  (Highest continuous step size)'
						NormVect=XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize));	%Rate vector for normalization
						[Ndown,Nup]=countdownup(NormVect);	%Max consecuitive steps
						Weight(end+1)=max([0,Ndown,Nup])^(h_AdvCond(cn).CondWeight);
						
						%---- options block
						MeanRateLeft=NormVect(h_AdvCond(cn).BoxSize+1)-NormVect(h_AdvCond(cn).BoxSize);	%rate before pike
						MeanRateRight=NormVect(h_AdvCond(cn).BoxSize+2)-NormVect(h_AdvCond(cn).BoxSize+1);	%rate after pike
						switch h_AdvCond(cn).Opt	%Main option of condition
						case 1	%Up or Down pike
							if (MeanRateLeft>0&MeanRateRight>0)|(MeanRateLeft<0&MeanRateRight<0)	%Pike
								Weight(end)=0;
							end
						case 2	%Up pike
							if ~(MeanRateLeft>0&MeanRateRight<0)
								Weight(end)=0;
							end
						case 3	%Down pike
							if ~(MeanRateLeft<0&MeanRateRight>0)
								Weight(end)=0;
							end
						case 4	%Any point
						end 
						
					case 13	%'pk wd'	->	'max(Value)-min(Value)/sign(time(max(Value))-time(min(Value)))  (Largest step within regiion)'
						%h_AdvCond(cn).BoxSize=h_AdvCond(cn).BoxSize*h_AdvCond(cn).CondWeight;
						NormVect=XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize));	%Rate vector for normalization
						[maxVal,maxValN]=max(NormVect);	%maximal value in the region
						[minVal,minValN]=min(NormVect);	%minimal value in the region
						Weight(end+1)=((maxVal-minVal)/sign(maxValN-minValN))^h_AdvCond(cn).CondWeight;	%Initial current condition weight - largest s
						
						%---- options block
						MeanRateLeft=NormVect(h_AdvCond(cn).BoxSize+1)-NormVect(h_AdvCond(cn).BoxSize);	%rate before pike
						MeanRateRight=NormVect(h_AdvCond(cn).BoxSize+2)-NormVect(h_AdvCond(cn).BoxSize+1);	%rate after pike
						switch h_AdvCond(cn).Opt	%Main option of condition
						case 1	%Up or Down pike
							if (MeanRateLeft>0&MeanRateRight>0)|(MeanRateLeft<0&MeanRateRight<0)	%Pike
								Weight(end)=0;
							end
						case 2	%Up pike
							if ~(MeanRateLeft>0&MeanRateRight<0)
								Weight(end)=0;
							end
						case 3	%Down pike
							if ~(MeanRateLeft<0&MeanRateRight>0)
								Weight(end)=0;
							end
						case 4	%Any point
						end %Main option of condition
					case 14	%'Mean'	->	'mean(Value)  (Low mean value regions)'
						switch h_AdvCond(cn).Opt	%Main option of condition
						case 1	%'All the values'
							Weight(end+1)=mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)))^h_AdvCond(cn).CondWeight;	%mean value in the analysed range
						case 2	%'Positive only'
							Weight(end+1)=mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)))^h_AdvCond(cn).CondWeight;	%mean value in the analysed range
							if Weight(end)<0
								Weight(end)=0;
							end
						case 3	%'Negative only'
							Weight(end+1)=mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)))^h_AdvCond(cn).CondWeight;	%mean value in the analysed range
							if Weight(end)>0
								Weight(end)=0;
							end
						case 4	%'Absolute value'
							Weight(end+1)=mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)))^h_AdvCond(cn).CondWeight;	%mean value in the analysed range
							Weight(end)=abs(Weight(end));
						case 5	%'Whole range'
							Weight(end+1)=(mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 6	%'_before'
							Weight(end+1)=(mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-1))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 7	%'_after'
							Weight(end+1)=(mean(XY(1,(i+1):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 8	%'min(_before,_after)'
							Weight(end+1)=min(abs([(mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-1))))^h_AdvCond(cn).CondWeight,...
								(mean(XY(1,(i+1):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
						case 9	%'max(_before,_after)'
							Weight(end+1)=max(abs([(mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-1))))^h_AdvCond(cn).CondWeight,...
								(mean(XY(1,(i+1):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
						case 10	%'Whole range side'
							Weight(end+1)=(mean(XY(1,[(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2)-1),(i+ceil(h_AdvCond(cn).BoxSize/2)+1):(i+h_AdvCond(cn).BoxSize)])))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 11	%'_side-before'
							Weight(end+1)=(mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2)-1))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 12	%'_side-after'
							Weight(end+1)=(mean(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/2)+1):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 13	%'min(_side-before,_side-after)'
							Weight(end+1)=min(abs([(mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2)-1))))^h_AdvCond(cn).CondWeight,...
								(mean(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/2)+1):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
						case 14	%'max(_side-before,_side-after)'
							Weight(end+1)=max(abs([(mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2)-1))))^h_AdvCond(cn).CondWeight,...
								(mean(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/2)+1):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
						end %Main option of condition
						
					case 15	%'Std. Dev.'	->	'std(Value)  (Noisy regions)'
						Weight(end+1)=std(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)))^h_AdvCond(cn).CondWeight;	%Standard deviation value in the analysed range
					case 16	%'Mean Rate'	->	'mean(Rate)  (Generally stable regions)'
% 						Weight(end+1)=mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight;	%mean rate value in the analysed range
% 						switch h_AdvCond(cn).Opt	%Main option of condition
% 						case 1	%'All the values'
% 						case 2	%'Positive only'
% 							if Weight(end)<0
% 								Weight(end)=0;
% 							end
% 						case 3	%'Negative only'
% 							if Weight(end)>0
% 								Weight(end)=0;
% 							end
% 						case 4	%'Absolute value'
% 							Weight(end)=abs(Weight(end));
% 						end %Main option of condition
						switch h_AdvCond(cn).Opt	%Main option of condition
						case 1	%'All the values'
							Weight(end+1)=mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight;	%mean value in the analysed range
						case 2	%'Positive only'
							Weight(end+1)=mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight;	%mean value in the analysed range
							if Weight(end)<0
								Weight(end)=0;
							end
						case 3	%'Negative only'
							Weight(end+1)=mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight;	%mean value in the analysed range
							if Weight(end)>0
								Weight(end)=0;
							end
						case 4	%'Absolute value'
							Weight(end+1)=mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight;	%mean value in the analysed range
							Weight(end)=abs(Weight(end));
						case 5	%'Whole range'
							Weight(end+1)=(mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 6	%'_before'
							Weight(end+1)=(mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i)))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 7	%'_after'
							Weight(end+1)=(mean(diff(XY(1,(i):(i+h_AdvCond(cn).BoxSize)))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 8	%'min(_before,_after)'
							Weight(end+1)=min(abs([(mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i)))))^h_AdvCond(cn).CondWeight,...
								(mean(diff(XY(1,(i):(i+h_AdvCond(cn).BoxSize)))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
						case 9	%'max(_before,_after)'
							Weight(end+1)=max(abs([(mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i)))))^h_AdvCond(cn).CondWeight,...
								(mean(diff(XY(1,(i1):(i+h_AdvCond(cn).BoxSize)))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
% 						case 6	%'_before'
% 							Weight(end+1)=(mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i-1)))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
% 						case 7	%'_after'
% 							Weight(end+1)=(mean(diff(XY(1,(i+1):(i+h_AdvCond(cn).BoxSize)))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
% 						case 8	%'min(_before,_after)'
% 							Weight(end+1)=min(abs([(mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i-1)))))^h_AdvCond(cn).CondWeight,...
% 								(mean(diff(XY(1,(i+1):(i+h_AdvCond(cn).BoxSize)))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
% 						case 9	%'max(_before,_after)'
% 							Weight(end+1)=max(abs([(mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i-1)))))^h_AdvCond(cn).CondWeight,...
% 								(mean(diff(XY(1,(i+1):(i+h_AdvCond(cn).BoxSize)))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
						case 10	%'Whole range side'
							Weight(end+1)=(mean(diff(XY(1,[(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2)-1),(i+ceil(h_AdvCond(cn).BoxSize/2)+1):(i+h_AdvCond(cn).BoxSize)]))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 11	%'_side-before'
							Weight(end+1)=(mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2)-1)))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 12	%'_side-after'
							Weight(end+1)=(mean(diff(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/2)+1):(i+h_AdvCond(cn).BoxSize)))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 13	%'min(_side-before,_side-after)'
							Weight(end+1)=min(abs([(mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2)-1)))))^h_AdvCond(cn).CondWeight,...
								(mean(diff(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/2)+1):(i+h_AdvCond(cn).BoxSize)))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
						case 14	%'max(_side-before,_side-after)'
							Weight(end+1)=max(abs([(mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2)-1)))))^h_AdvCond(cn).CondWeight,...
								(mean(diff(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/2)+1):(i+h_AdvCond(cn).BoxSize)))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
						end %Main option of condition
						
						
					case 17	%'Std. Dev. Rate'	->	'std(Rate)  (Unstable rate regions)'
						Weight(end+1)=std(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight;	%standard deviation of the rate value in the analysed range
					case 18	%'Point - Mean'	->	'Point_value-mean(Value)  (Points far from the mean value in region)'
						
						switch h_AdvCond(cn).Opt	%Main option of condition
						case 1	%'Whole range'
							Weight(end+1)=(XY(1,i)-mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 2	%'_before'
							Weight(end+1)=(XY(1,i)-mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-1))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 3	%'_after'
							Weight(end+1)=(XY(1,i)-mean(XY(1,(i+1):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 4	%'min(_before,_after)'
% 							Weight(end+1)=min(abs([(XY(1,i)-mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-1))))^h_AdvCond(cn).CondWeight,...
% 								(XY(1,i)-mean(XY(1,(i+1):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
							Weight(end+1)=min(([(XY(1,i)-mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-1))))^h_AdvCond(cn).CondWeight,...
								(XY(1,i)-mean(XY(1,(i+1):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
						%
						case 5	%'max(_before,_after)'
							Weight(end+1)=max(([(XY(1,i)-mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-1))))^h_AdvCond(cn).CondWeight,...
								(XY(1,i)-mean(XY(1,(i+1):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
						case 6	%'Whole range side'
							Weight(end+1)=(XY(1,i)-mean(XY(1,[(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2)-1),(i+ceil(h_AdvCond(cn).BoxSize/2)+1):(i+h_AdvCond(cn).BoxSize)])))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 7	%'_side-before'
							Weight(end+1)=(XY(1,i)-mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2)-1))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 8	%'_side-after'
							Weight(end+1)=(XY(1,i)-mean(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/2)+1):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight;	%difference between the poind and the mean value in the analysed range
						case 9	%'min(_side-before,_side-after)'
							Weight(end+1)=min(([(XY(1,i)-mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2)-1))))^h_AdvCond(cn).CondWeight,...
								(XY(1,i)-mean(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/2)+1):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
						case 10	%'max(_side-before,_side-after)'
							Weight(end+1)=max(([(XY(1,i)-mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2)-1))))^h_AdvCond(cn).CondWeight,...
								(XY(1,i)-mean(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/2)+1):(i+h_AdvCond(cn).BoxSize))))^h_AdvCond(cn).CondWeight]));	%difference between the poind and the mean value in the analysed range
						end %Main option of condition
						
					case 19	%'(Mean_aft-Mean_bfr)'	->	
						switch h_AdvCond(cn).Opt	%Main option of condition
						case {1 2 3 4}	%'All the values','Positive only','Negative only','Absolute value'
							Range_before=(i-h_AdvCond(cn).BoxSize):(i-1);
							Range_after=(i+1):(i+h_AdvCond(cn).BoxSize);
						case {5 6 7 8}	%'All the values _side','Positive only _side','Negative only _side','Absolute value _side'
							Range_before=(i-h_AdvCond(cn).BoxSize):(i-1);
							Range_after=(i+1):(i+h_AdvCond(cn).BoxSize);
						end	%Main option of condition
						Weight(end+1)=(mean(XY(1,Range_after))-...
							mean(XY(1,Range_before)))^h_AdvCond(cn).CondWeight;	%difference of mean values afer and before the point in the the analysed range

						switch h_AdvCond(cn).Opt	%Main option of condition
						case {1 5}	%'All the values','All the values _side'
						case {2 6}	%'Positive only','Positive only _side'
							if Weight(end)<0
								Weight(end)=0;
							end
						case {3	7}%'Negative only','Negative only _side'
							if Weight(end)>0
								Weight(end)=0;
							end
						case {4 8}	%'Absolute value','Absolute value _side'
							Weight(end)=abs(Weight(end));
						end %Main option of condition
						
					case 20	%'(Mean_aft-Mean_bfr)/Mean(Std_aft,Std_bfr)'}	->	'(mean(Value_after)-mean(Value_before))/mean([std(Value_after),std(Value_before)])  (Step between two low-noise regions)'
						switch h_AdvCond(cn).Opt	%Main option of condition
						case {1 2 3 4}	%'All the values','Positive only','Negative only','Absolute value'
							Range_before=(i-h_AdvCond(cn).BoxSize):(i-1);
							Range_after=(i+1):(i+h_AdvCond(cn).BoxSize);
						case {5 6 7 8}	%'All the values _side','Positive only _side','Negative only _side','Absolute value _side'
							Range_before=(i-h_AdvCond(cn).BoxSize):(i-1);
							Range_after=(i+1):(i+h_AdvCond(cn).BoxSize);
						end	%Main option of condition
						Weight(end+1)=((mean(XY(1,Range_after))-...
							mean(XY(1,Range_before)))/...
							mean([std(XY(1,Range_after)),...
								std(XY(1,Range_before))]))^h_AdvCond(cn).CondWeight;	%difference of mean values afer and before the point in the the analysed range, divided by the mean standard deviation in these regions
						
						switch h_AdvCond(cn).Opt	%Main option of condition
						case {1 5}	%'All the values','All the values _side'
						case {2 6}	%'Positive only','Positive only _side'
							if Weight(end)<0
								Weight(end)=0;
							end
						case {3	7}%'Negative only','Negative only _side'
							if Weight(end)>0
								Weight(end)=0;
							end
						case {4 8}	%'Absolute value','Absolute value _side'
							Weight(end)=abs(Weight(end));
						end %Main option of condition
						
					case 21	%'(Mean_aft-Mean_bfr)/Min(Std_aft,Std_bfr)'}	->	'(mean(Value_after)-mean(Value_before))/min([std(Value_after),std(Value_before)])  (Step near low-noise region)'
						switch h_AdvCond(cn).Opt	%Main option of condition
						case {1 2 3 4}	%'All the values','Positive only','Negative only','Absolute value'
							Range_before=(i-h_AdvCond(cn).BoxSize):(i-1);
							Range_after=(i+1):(i+h_AdvCond(cn).BoxSize);
						case {5 6 7 8}	%'All the values _side','Positive only _side','Negative only _side','Absolute value _side'
							Range_before=(i-h_AdvCond(cn).BoxSize):(i-1);
							Range_after=(i+1):(i+h_AdvCond(cn).BoxSize);
						end	%Main option of condition
						Weight(end+1)=((mean(XY(1,Range_after))-...
							mean(XY(1,Range_before)))/...
							min(std(XY(1,Range_after)),...
							std(XY(1,Range_before))))^h_AdvCond(cn).CondWeight;	%difference of mean values afer and before the point in the the analysed range, divided by the minimal standard deviation in these regions
						
						switch h_AdvCond(cn).Opt	%Main option of condition
						case {1 5}	%'All the values','All the values _side'
						case {2 6}	%'Positive only','Positive only _side'
							if Weight(end)<0
								Weight(end)=0;
							end
						case {3	7}%'Negative only','Negative only _side'
							if Weight(end)>0
								Weight(end)=0;
							end
						case {4 8}	%'Absolute value','Absolute value _side'
							Weight(end)=abs(Weight(end));
						end %Main option of condition
						
					case 22	%'mean(Value_after#)-mean(Value_before#)  (Wide step regions)'

						switch h_AdvCond(cn).Opt	%Main option of condition
						case 1	%'Point middle'
							Weight(end+1)=mean(XY(1,(i+1):(i+h_AdvCond(cn).BoxSize)))-...
								mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-1)));
						case 2	%'Mean middle'
							Weight(end+1)=mean(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/2)):(i+h_AdvCond(cn).BoxSize)))-...
								mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2))));
						case 3	%'Min of 3 diff'
							MeanBefore=mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-(ceil(h_AdvCond(cn).BoxSize/2)+1))));
							MeanMiddle=mean(XY(1,(i-ceil(h_AdvCond(cn).BoxSize/2)):(i+ceil(h_AdvCond(cn).BoxSize/2))));
							MeanAfter=mean(XY(1,(i+(ceil(h_AdvCond(cn).BoxSize/2)+1)):(i+h_AdvCond(cn).BoxSize)));
							MeanDiffs=[abs(MeanMiddle-MeanBefore),abs(MeanAfter-MeanMiddle),abs(MeanAfter-MeanBefore)];
							Weight(end+1)=min(MeanDiffs);
						case 4	%'Max of 3 diff'
							MeanBefore=mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-(ceil(h_AdvCond(cn).BoxSize/2)+1))));
							MeanMiddle=mean(XY(1,(i-ceil(h_AdvCond(cn).BoxSize/2)):(i+ceil(h_AdvCond(cn).BoxSize/2))));
							MeanAfter=mean(XY(1,(i+(ceil(h_AdvCond(cn).BoxSize/2)+1)):(i+h_AdvCond(cn).BoxSize)));
							MeanDiffs=[abs(MeanMiddle-MeanBefore),abs(MeanAfter-MeanMiddle),abs(MeanAfter-MeanBefore)];
							Weight(end+1)=max(MeanDiffs);
						case 5	%'Min of 4 diff'
							MeanBefore=mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-(ceil(h_AdvCond(cn).BoxSize/2)+1))));
							MeanMiddleBefore=mean(XY(1,(i-ceil(h_AdvCond(cn).BoxSize/2)):(i-1)));
							MeanMiddleAfter=mean(XY(1,(i+1):(i+ceil(h_AdvCond(cn).BoxSize/2))));
							MeanAfter=mean(XY(1,(i+(ceil(h_AdvCond(cn).BoxSize/2)+1)):(i+h_AdvCond(cn).BoxSize)));
							MeanDiffs=[abs(MeanMiddleAfter-MeanMiddleBefore),abs(MeanMiddleAfter-MeanBefore),abs(MeanAfter-MeanMiddleBefore),abs(MeanAfter-MeanBefore)];
							Weight(end+1)=min(MeanDiffs);
						case 6	%'Min of 6/2 diff'
							MeanBefore=mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(2*h_AdvCond(cn).BoxSize/3)-1)));
							MeanMiddleBefore=mean(XY(1,(i-ceil(2*h_AdvCond(cn).BoxSize/3)):(i-ceil(h_AdvCond(cn).BoxSize/3)-1)));
							MeanCenterBefore=mean(XY(1,(i-ceil(h_AdvCond(cn).BoxSize/3)):(i-1)));
							MeanCenterAfter=mean(XY(1,(i+1):(i+ceil(h_AdvCond(cn).BoxSize/3))));
							MeanMiddleAfter=mean(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/3)+1):(i+ceil(2*h_AdvCond(cn).BoxSize/3))));
							MeanAfter=mean(XY(1,(i+ceil(2*h_AdvCond(cn).BoxSize/3)+1):(i+h_AdvCond(cn).BoxSize)));
%							MeanDiffs=[abs(MeanCenterAfter-MeanBefore),abs(MeanMiddleAfter-MeanMiddleBefore),abs(MeanAfter-MeanCenterBefore),abs(MeanAfter-MeanBefore),abs(MeanMiddleAfter-MeanMiddleBefore),abs(MeanCenterAfter-MeanCenterBefore),abs(MeanCenterAfter-MeanMiddleBefore),abs(MeanMiddleAfter-MeanCenterBefore)];
%							MeanDiffs=[abs(MeanCenterAfter-MeanBefore),abs(MeanMiddleAfter-MeanMiddleBefore),abs(MeanAfter-MeanCenterBefore),abs(MeanAfter-MeanBefore),abs(MeanMiddleAfter-MeanMiddleBefore),abs(MeanCenterAfter-MeanCenterBefore)];
							MeanDiffs=[abs(MeanCenterAfter-MeanBefore),abs(MeanMiddleAfter-MeanMiddleBefore),abs(MeanAfter-MeanCenterBefore),abs(MeanAfter-MeanBefore)];
%							MeanDiffs=[abs(MeanCenterAfter-MeanBefore),abs(MeanMiddleAfter-MeanMiddleBefore),abs(MeanAfter-MeanCenterBefore)];
%							Weight(end+1)=mean(MeanDiffs);
%							Weight(end+1)=max(MeanDiffs);
							Weight(end+1)=min(MeanDiffs);
						case 7	%'Mean of 7 diff'
							MeanBefore=mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(2*h_AdvCond(cn).BoxSize/3)-1)));
							MeanMiddleBefore=mean(XY(1,(i-ceil(2*h_AdvCond(cn).BoxSize/3)):(i-ceil(h_AdvCond(cn).BoxSize/3)-1)));
							MeanCenterBefore=mean(XY(1,(i-ceil(h_AdvCond(cn).BoxSize/3)):(i-1)));
							MeanCenterAfter=mean(XY(1,(i+1):(i+ceil(h_AdvCond(cn).BoxSize/3))));
							MeanMiddleAfter=mean(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/3)+1):(i+ceil(2*h_AdvCond(cn).BoxSize/3))));
							MeanAfter=mean(XY(1,(i+ceil(2*h_AdvCond(cn).BoxSize/3)+1):(i+h_AdvCond(cn).BoxSize)));
							MeanDiffs=[abs(MeanCenterAfter-MeanBefore),abs(MeanMiddleAfter-MeanMiddleBefore),abs(MeanAfter-MeanCenterBefore),abs(MeanAfter-MeanBefore),abs(MeanCenterAfter-MeanCenterBefore),abs(MeanCenterAfter-MeanMiddleBefore),abs(MeanMiddleAfter-MeanCenterBefore)];
%							MeanDiffs=[abs(MeanCenterAfter-MeanBefore),abs(MeanMiddleAfter-MeanMiddleBefore),abs(MeanAfter-MeanCenterBefore),abs(MeanAfter-MeanBefore),abs(MeanMiddleAfter-MeanMiddleBefore),abs(MeanCenterAfter-MeanCenterBefore)];
%							MeanDiffs=[abs(MeanCenterAfter-MeanBefore),abs(MeanMiddleAfter-MeanMiddleBefore),abs(MeanAfter-MeanCenterBefore),abs(MeanAfter-MeanBefore)];
%							MeanDiffs=[abs(MeanCenterAfter-MeanBefore),abs(MeanMiddleAfter-MeanMiddleBefore),abs(MeanAfter-MeanCenterBefore)];
							Weight(end+1)=mean(MeanDiffs);
%							Weight(end+1)=max(MeanDiffs);
%							Weight(end+1)=min(MeanDiffs);
						case 8	%'Point middle averaged'
							MeanDiffs=[];
							for ij=1:h_AdvCond(cn).BoxSize
								MeanDiffs(ij)=mean(XY(1,(i+1):(i+ij)))-mean(XY(1,(i-ij):(i-1)));
							end
% 							MeanBefore=mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(2*h_AdvCond(cn).BoxSize/3)-1)));
% 							MeanMiddleBefore=mean(XY(1,(i-ceil(2*h_AdvCond(cn).BoxSize/3)):(i-ceil(h_AdvCond(cn).BoxSize/3)-1)));
% 							MeanCenterBefore=mean(XY(1,(i-ceil(h_AdvCond(cn).BoxSize/3)):(i-1)));
% 							MeanCenterAfter=mean(XY(1,(i+1):(i+ceil(h_AdvCond(cn).BoxSize/3))));
% 							MeanMiddleAfter=mean(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/3)+1):(i+ceil(2*h_AdvCond(cn).BoxSize/3))));
% 							MeanAfter=mean(XY(1,(i+ceil(2*h_AdvCond(cn).BoxSize/3)+1):(i+h_AdvCond(cn).BoxSize)));
% 							MeanDiffs=[(MeanCenterAfter-MeanCenterBefore),(MeanMiddleAfter-MeanMiddleBefore),(MeanAfter-MeanBefore)];
%							MeanDiffs=[(MeanCenterAfter-MeanCenterBefore),(MeanAfter-MeanMiddleAfter),(MeanMiddleBefore-MeanBefore)];
% 							if (sign(MeanDiffs(2)-MeanDiffs(1))~=sign(MeanDiffs(3)-MeanDiffs(1)))	%Narrow pike
% 								%Weight(end+1)=mean(MeanDiffs);
% 								Weight(end+1)=MeanDiffs(1);
% 							elseif (sign(MeanDiffs(1)-MeanDiffs(3))~=sign(MeanDiffs(2)-MeanDiffs(3)))	%Narrow pike
% 								%Weight(end+1)=mean(MeanDiffs);
% 								Weight(end+1)=MeanDiffs(3);
% 							else
% 								Weight(end+1)=MeanDiffs(2);
% 							end
							Weight(end+1)=mean(MeanDiffs);
						case 9	%'*mean(Rate)'
% 							Weight(end+1)=(mean(XY(1,(i+1):(i+h_AdvCond(cn).BoxSize)))-...
% 								mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-1))))*mean(diff(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize))));
							Weight(end+1)=(mean(XY(1,(i+1):(i+h_AdvCond(cn).BoxSize)))-...
								mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-1))))*(mean(XY(1,(i+ceil(h_AdvCond(cn).BoxSize/2)+1):(i+h_AdvCond(cn).BoxSize)))-mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i-ceil(h_AdvCond(cn).BoxSize/2)-1))));
							
						end %Main option of condition
                    case 23 %Point after
                        Weight(end+1)=XY(1,(i+h_AdvCond(cn).BoxSize));
                    case 24 %point before
                        Weight(end+1)=XY(1,(i-h_AdvCond(cn).BoxSize));
					end	%Type of weighting coefficient.
					
					%---- range fit checking block
					if h_AdvCond(cn).RangeType>1	%Range type for the calculated coefficient will be checked
						switch h_AdvCond(cn).RangeUnits	%Units of box size
						case 1	%'Neighbors'
							MinCn=BinsX(min(length(BinsX),max(1,h_AdvCond(cn).Min))); %Minimal value of the range
							MaxCn=BinsX(min(length(BinsX),max(1,h_AdvCond(cn).Max)));	%Maximal value of the range
						case 2	%'Absolute'
							MinCn=h_AdvCond(cn).Min; %Minimal value of the range
							MaxCn= h_AdvCond(cn).Max;	%Maximal value of the range
						case 3	%'Mean'
							MeanCn=mean(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)));	%mean value in the analysed range
							MinCn=h_AdvCond(cn).Min*MeanCn; %Minimal value of the range
							MaxCn= h_AdvCond(cn).Max*MeanCn;	%Maximal value of the range
						case 4	%'St. Dev.'});
							StdCn=std(XY(1,(i-h_AdvCond(cn).BoxSize):(i+h_AdvCond(cn).BoxSize)));	%St. deviation value in the analysed range
							MinCn=h_AdvCond(cn).Min*StdCn; %Minimal value of the range
							MaxCn= h_AdvCond(cn).Max*StdCn;	%Maximal value of the range
						end	%Units of box size
						
						
						
						switch h_AdvCond(cn).RangeType	%Range type for the calculated coefficient to fit into to be included into the histogram
						case 1	%'(None)'
							%Do nothing
						case 2	%'Min<W<Max'
							if MinCn<Weight(end)&Weight(end)<MaxCn; Weight(end)=1; else Weight(end)=0; end
						case 3	%'Min<=W<=Max'
							if MinCn<=Weight(end)&Weight(end)<=MaxCn; Weight(end)=1; else Weight(end)=0; end
						case 4	%'Min<W'
							if MinCn<Weight(end); Weight(end)=1; else Weight(end)=0; end
						case 5	%'Min<=W'
							if MinCn<=Weight(end); Weight(end)=1; else Weight(end)=0; end
						case 6	%'W<Max'
							if Weight(end)<MaxCn; Weight(end)=1; else Weight(end)=0; end
						case 7	%'W<=Max'
							if Weight(end)<=MaxCn; Weight(end)=1; else Weight(end)=0; end
						case 8	%'~(Min<W<Max)'
							if ~(MinCn<Weight(end)&Weight(end)<MaxCn); Weight(end)=1; else Weight(end)=0; end
						case 9	%'~(Min<=W<=Max)'
							if ~(MinCn<=Weight(end)&Weight(end)<=MaxCn); Weight(end)=1; else Weight(end)=0; end
						end	%Range type for the calculated coefficient to fit into to be included into the histogram
					end	%Range type for the calculated coefficient will be checked
				end	%This condition is used
			end	%Cycle through the conditions
		case 6	%Y weighting (Pressure or time)
			Weight(end)=1;
		end	%Type of Z axis normalization: 'Z Absolute' <1>,'Z/(All pnts)' <2>,'Z/(X pnts)' <3>,'Z/(Y pnts)' <4>,'Z*(X wght)' <5>,'Z*(Y wght)' <6>
		
		if isempty(Weight)	%No conditions were used
			Weight=1;
		end	%No conditions were used
		
		%------ Weights combination for all the conditions
		switch h_UseAdvCond	%Mode of combining of several advanced conditions
		case 1	%'Don''t use advanced conditions'
			Weight=Weight(1);
		case 2	%'Combine advanced conditions as "AND"'
			Weight=prod(Weight(:));
		case 3	%'Combine advanced conditions as "OR"'
			Weight=sum(Weight(:));
		case 4	%'Combine advanced conditions as "~(AND)"'
			Weight=1-prod(Weight(:));
		case 5	%'Combine advanced conditions as "~(OR)"'
			Weight=1-sum(Weight(:));
		end	%Mode of combining of several advanced conditions

		
		Hst(PointX,PointY)=Hst(PointX,PointY)+Weight;
		if size(OutCntrData,2)>0	%Control output trace file
			OutCntrData(2,i)=Weight;
			if Weight==0	%Point is not included
				OutCntrData(1,i)=0;
			end	%Point is not included
		end	%Control output trace file
	else	%Point coordinates are out of hisogram matrix range
		if size(OutCntrData,2)>0	%Control output trace file
			OutCntrData(:,i)=0;	%Point is not included
		end	%Control output trace file
	end	%Point coordinates are within hisogram matrix range
	PointY=max(1,min(SizeY,PointY));	%Limiting the maximum value
	PointX=max(1,min(SizeX,PointX));	%Limiting the maximum value
end	%Cycle through XY data matrix

switch NormZN	%Type of Z axis normalization: 'Z Absolute' <1>,'Z/(All pnts)' <2>,'Z/(X pnts)' <3>,'Z/(Y pnts)' <4>,'Z*(X wght)' <5>,'Z*(Y wght)' <6>
	case 1	%'Z Absolute' <1*> - no normalization
	case 2	%'Z/All pnts'
		Hst=Hst/sum(sum(Hst));
	case 3	%'Z/X pnts' 
		HstD=sum(Hst,2); %1-dimensional sum histogram
		for i=1:length(HstD)	%Normalizing lines which are above treshold
			if (sum(Hst(i,:))~=0)
				Hst(i,:)=Hst(i,:)/sum(Hst(i,:));
			end
		end
	case 4	%'Z/Y pnts'
		HstD=sum(Hst,1); %1-dimensional sum histogram
		for i=1:length(HstD)	%Normalizing lines which are above treshold
			if (sum(Hst(:,i))~=0)
				Hst(:,i)=Hst(:,i)/sum(Hst(:,i));
			end
		end
end
SndN(1);

function [XY,XYadd]=elongate(XY,XYadd,FirstTimeRead,TimeRng);

%inputs:
%XY -	2-row initial data matrix
%XYadd -	New addition piece (last part of the current data matrix) for the next step
%FirstTimeRead -		Flag for the first step of reading file <1> - yes, <0> - no
%TimeRng -	Length of the time period (in points) to add

%Outputs:
%XY -	2-row elongated data matrix
%XYadd -	New addition piece (last part of the current data matrix) for the next step

if TimeRng~=0
	if FirstTimeRead==1
		%FirstTimeRead=0;
	else
		XY=[XYadd XY];
	end
	XYadd=XY(:,(end-2*TimeRng+1):end);
end

function [Ndown,Nup]=countdownup(NormVect)
%counts maximum nunber of consecuentive steps in each direction - up and down - in current

%inputs:
%NormVect - vector to look through

%Outputs:
%Ndown		- number of consecuitive steps down
%Nup		- number of consecuitive steps up

%initial values
Ndown=1;
Nup=1;

%counting cycle
for i=2:length(NormVect)
	if NormVect(i)>NormVect(i-1)	%step up
		Ndown=1;
		Nup=Nup+1;
	elseif NormVect(i)<NormVect(i-1)
		Ndown=Ndown+1;
		Nup=1;
	end
end


